@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -293,7 +293,7 @@ void computeInitialPose(vpCameraParameters *mcam, vpImage<unsigned char> &I,
       }
     }
   }
-  catch(vpException e){
+  catch(vpException &e){
     vpERROR_TRACE("Error while tracking dots") ;
     vpCTRACE << e;
     return;
@@ -576,11 +576,11 @@ int main(int argc, const char **argv)
     grabber.close();
     return 0;
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return 1;
   }
-  catch(Ogre::Exception e) {
+  catch(Ogre::Exception &e) {
     std::cout << "Catch an Ogre exception: " << e.getDescription() << std::endl;
     return 1;
   }
