@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -142,7 +142,7 @@ main()
     robot.getCameraParameters (cam, I);
     std::cout << "define the initial segment" << std::endl;
 
-    for(std::vector<vpDot>::iterator i = dot.begin();i!=dot.end();i++){
+    for(std::vector<vpDot>::iterator i = dot.begin();i!=dot.end(); ++i){
       std::cout << "Click on a dot..." << std::endl;
       i->initTracking(I) ;
       cog = i->getCog();
@@ -153,7 +153,7 @@ main()
     seg.display(cam,I,vpColor::red);
     vpDisplay::flush(I);
     std::cout << "define the destination segment" << std::endl;
-    for(std::vector<vpDot>::iterator i = dot_d.begin();i!=dot_d.end();i++){
+    for(std::vector<vpDot>::iterator i = dot_d.begin();i!=dot_d.end(); ++i){
       vpImagePoint ip;
       vpDisplay::getClick(I,ip);
       *i = vpDot(ip);
@@ -192,7 +192,7 @@ main()
       vpDisplay::display(I) ;
 
       // Achieve the tracking of the dot in the image
-      for(std::vector<vpDot>::iterator i = dot.begin();i!=dot.end();i++){
+      for(std::vector<vpDot>::iterator i = dot.begin();i!=dot.end(); ++i){
         i->track(I) ;
       }
 
