@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,7 +65,7 @@ vpDisplayX *d;
 vpDisplayGDI *d;
 #endif
 vpImage<unsigned char> I;
-static int isInitialized = false;
+static bool isInitialized = false;
 static int half_size = 256*2;
 
 void sonarPrinter(void)
@@ -347,7 +347,7 @@ int main(int argc, char **argv)
     ArLog::log(ArLog::Normal, "simpleMotionCommands: Exiting.");
     return 0;
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return 1;
   }
