@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -106,11 +106,11 @@ int main ()
     vpDisplay::getClick(plot.I);
 
     //Save the datas as text files
-    plot.saveData(0, "dataCos.txt");
-    plot.saveData(0, "dataSin.txt");
+    plot.saveData(0, "dataCos.txt", "# ");
+    plot.saveData(1, "dataSin.txt", "# ");
     return 0;
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return 1;
   }
