@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -60,12 +60,12 @@
 #include <visp3/io/vpParseArgv.h>
 #include <visp3/mbt/vpMbKltTracker.h>
 
-#define GETOPTARGS  "x:m:i:n:dchtfolw"
+#define GETOPTARGS  "x:m:i:n:dchtfolwv"
 
 void usage(const char *name, const char *badparam);
 bool getOptions(int argc, const char **argv, std::string &ipath, std::string &configFile, std::string &modelFile,
-                std::string &initFile, bool &displayKltPoints, bool &click_allowed, bool &display,
-                bool& cao3DModel, bool &useOgre);
+    std::string &initFile, bool &displayKltPoints, bool &click_allowed, bool &display,
+    bool& cao3DModel, bool &useOgre, bool &showOgreConfigDialog, bool &useScanline, bool &computeCovariance);
 
 void usage(const char *name, const char *badparam)
 {
@@ -75,7 +75,7 @@ Example of tracking based on the 3D model.\n\
 SYNOPSIS\n\
   %s [-i <test image path>] [-x <config file>]\n\
   [-m <model name>] [-n <initialisation file base name>]\n\
-  [-t] [-c] [-d] [-h] [-f] [-o] [-w] [-l]",
+  [-t] [-c] [-d] [-h] [-f] [-o] [-w] [-l] [-v]",
   name );
 
   fprintf(stdout, "\n\
@@ -126,7 +126,10 @@ OPTIONS:                                               \n\
      When Ogre3D is enable [-o] show Ogre3D configuration dialog thatallows to set the renderer.\n\
 \n\
   -l\n\
-     Use the scanline for visibility tests\n\
+     Use the scanline for visibility tests.\n\
+\n\
+  -v\n\
+     Compute covariance matrix.\n\
 \n\
   -h \n\
      Print the help.\n\n");
@@ -138,7 +141,7 @@ OPTIONS:                                               \n\
 
 bool getOptions(int argc, const char **argv, std::string &ipath, std::string &configFile, std::string &modelFile,
                 std::string &initFile, bool &displayKltPoints, bool &click_allowed, bool &display,
-                bool& cao3DModel, bool &useOgre, bool &showOgreConfigDialog, bool &useScanline)
+                bool& cao3DModel, bool &useOgre, bool &showOgreConfigDialog, bool &useScanline, bool &computeCovariance)
 {
   const char *optarg_;
   int   c;
@@ -156,6 +159,7 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &co
     case 'o': useOgre = true; break;
     case 'l': useScanline = true; break;
     case 'w': showOgreConfigDialog  = true; break;
+    case 'v': computeCovariance  = true; break;
     case 'h': usage(argv[0], NULL); return false; break;
 
     default:
@@ -195,6 +199,7 @@ main(int argc, const char ** argv)
     bool useOgre = false;
     bool showOgreConfigDialog = false;
     bool useScanline = false;
+    bool computeCovariance = false;
     bool quit = false;
 
     // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH environment variable value
@@ -206,7 +211,8 @@ main(int argc, const char ** argv)
 
     // Read the command line options
     if (!getOptions(argc, argv, opt_ipath, opt_configFile, opt_modelFile, opt_initFile, displayKltPoints,
-                    opt_click_allowed, opt_display, cao3DModel, useOgre, showOgreConfigDialog, useScanline)) {
+                    opt_click_allowed, opt_display, cao3DModel, useOgre, showOgreConfigDialog, useScanline,
+                    computeCovariance)) {
       return (-1);
     }
 
@@ -359,6 +365,9 @@ main(int argc, const char ** argv)
     // Tells if the tracker has to use the scanline visibility tests
     tracker.setScanLineVisibilityTest(useScanline);
 
+    // Tells if the tracker has to compute the covariance matrix
+    tracker.setCovarianceComputation(computeCovariance);
+
     // Retrieve the camera parameters from the tracker
     tracker.getCameraParameters(cam);
 
@@ -399,9 +408,6 @@ main(int argc, const char ** argv)
     if (opt_display)
       vpDisplay::flush(I);
 
-    // Uncomment if you want to compute the covariance matrix.
-    // tracker.setCovarianceComputation(true); //Important if you want tracker.getCovarianceMatrix() to work.
-
     while (!reader.end())
     {
       // acquire a new image
@@ -447,6 +453,7 @@ main(int argc, const char ** argv)
         tracker.setCameraParameters(cam);
         tracker.setOgreVisibilityTest(useOgre);
         tracker.setScanLineVisibilityTest(useScanline);
+        tracker.setCovarianceComputation(computeCovariance);
         tracker.initFromPose(I, cMo);
       }
 
@@ -487,9 +494,9 @@ main(int argc, const char ** argv)
         }
       }
 
-      // Uncomment if you want to print the covariance matrix.
-      // Make sure tracker.setCovarianceComputation(true) has been called (uncomment below).
-      // std::cout << tracker.getCovarianceMatrix() << std::endl << std::endl;
+      if(computeCovariance) {
+        std::cout << "Covariance matrix: \n" << tracker.getCovarianceMatrix() << std::endl << std::endl;
+      }
 
       vpDisplay::flush(I) ;
     }
@@ -513,7 +520,7 @@ main(int argc, const char ** argv)
 
     return 0;
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return 1;
   }
