@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -164,13 +164,12 @@ void vpMatrix::LUBksb(unsigned int *perm, vpColVector& b)
   unsigned int n = rowNum;
 
   unsigned int ii=0;
-  unsigned int ip;
   double sum_;
   bool flag = false;
   unsigned int i;
 
   for (i=0;i<n;i++) {
-    ip=perm[i];
+    unsigned int ip=perm[i];
     sum_=b[ip];
     b[ip]=b[i];
     if (flag) {
@@ -254,12 +253,12 @@ vpMatrix::inverseByLU() const
   A = *this;
 
   unsigned int *perm = new unsigned int[rowNum];
-  int p;
 
   try {
+    int p;
     A.LUDcmp(perm, p);
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     delete [] perm;
     throw(e);
   }
