@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,6 +52,11 @@
 
 //using namespace X11name ;
 
+// Work arround to use this class with Eigen3
+#ifdef Success
+#  undef Success // See http://eigen.tuxfamily.org/bz/show_bug.cgi?id=253
+#endif
+
 #include <visp3/core/vpImage.h>
 #include <visp3/core/vpRect.h>
 
@@ -68,9 +73,9 @@
 
   \ingroup group_gui_display
 
-  \brief Define the X11 console to display images.
-
-  \note Ready to use with a Unix System (tested for Linux and SunOS)
+  \brief Use the X11 console to display images on unix-like OS.
+  Thus to enable this class X11 should be installed. Installation
+  instructions are provided here https://visp.inria.fr/3rd_x11.
 
   This class define the X11 console to display  images
   It also define method to display some geometric feature (point, line, circle)
@@ -120,21 +125,21 @@ int main()
   vpDisplay::flush(I);
 
   // Get non blocking keyboard events
-  std::cout << "Check keyboard events..." << std::endl; 
+  std::cout << "Check keyboard events..." << std::endl;
   char key[10];
   bool ret;
   for (int i=0; i< 200; i++) {
     bool ret = vpDisplay::getKeyboardEvent(I, key, false);
-    if (ret) 
+    if (ret)
       std::cout << "keyboard event: key: " << "\"" << key << "\"" << std::endl;
     vpTime::wait(40);
   }
 
   // Get a blocking keyboard event
-  std::cout << "Wait for a keyboard event..." << std::endl; 
+  std::cout << "Wait for a keyboard event..." << std::endl;
   ret = vpDisplay::getKeyboardEvent(I, key, true);
   std::cout << "keyboard event: " << ret << std::endl;
-  if (ret) 
+  if (ret)
     std::cout << "key: " << "\"" << key << "\"" << std::endl;
 
   // Wait for a click in the display window
@@ -165,124 +170,97 @@ private:
   unsigned int RMask, GMask, BMask;
   int RShift, GShift, BShift;
 
-//private:
-//#ifndef DOXYGEN_SHOULD_SKIP_THIS
-//  vpDisplayX(const vpDisplayX &)
-//    : vpDisplay(), display(NULL), window(), Ximage(NULL), lut(), context(), screen(), event(), pixmap(),
-//      x_color(NULL), screen_depth(8), xcolor(), values(), ximage_data_init(false),
-//      RMask(0), GMask(0), BMask(0), RShift(0), GShift(0), BShift(0)
-//  {
-//    throw vpException(vpException::functionNotImplementedError, "Not implemented!");
-//  }
-//  vpDisplayX &operator=(const vpDisplayX &){
-//    throw vpException(vpException::functionNotImplementedError, "Not implemented!");
-//    return *this;
-//  }
-//#endif
+  //private:
+  //#ifndef DOXYGEN_SHOULD_SKIP_THIS
+  //  vpDisplayX(const vpDisplayX &)
+  //    : vpDisplay(), display(NULL), window(), Ximage(NULL), lut(), context(), screen(), event(), pixmap(),
+  //      x_color(NULL), screen_depth(8), xcolor(), values(), ximage_data_init(false),
+  //      RMask(0), GMask(0), BMask(0), RShift(0), GShift(0), BShift(0)
+  //  {
+  //    throw vpException(vpException::functionNotImplementedError, "Not implemented!");
+  //  }
+  //  vpDisplayX &operator=(const vpDisplayX &){
+  //    throw vpException(vpException::functionNotImplementedError, "Not implemented!");
+  //    return *this;
+  //  }
+  //#endif
 
 public:
   vpDisplayX() ;
-  vpDisplayX(int winx, int winy, const char *title=NULL) ;
-  vpDisplayX(vpImage<unsigned char> &I, int winx=-1, int winy=-1,
-             const char *title=NULL) ;
-  vpDisplayX(vpImage<vpRGBa> &I, int winx=-1, int winy=-1,
-             const char *title=NULL) ;
+  vpDisplayX(int winx, int winy, const std::string &title="") ;
+  vpDisplayX(vpImage<unsigned char> &I, vpScaleType type);
+  vpDisplayX(vpImage<unsigned char> &I, int winx=-1, int winy=-1, const std::string &title="", vpScaleType type=SCALE_DEFAULT) ;
+  vpDisplayX(vpImage<vpRGBa> &I, vpScaleType type);
+  vpDisplayX(vpImage<vpRGBa> &I, int winx=-1, int winy=-1, const std::string &title="", vpScaleType type=SCALE_DEFAULT) ;
 
   virtual ~vpDisplayX() ;
-
-  void init(vpImage<unsigned char> &I,
-            int winx=-1, int winy=-1,
-            const char *title=NULL)  ;
-  void init(vpImage<vpRGBa> &I,
-            int winx=-1, int winy=-1,
-            const char *title=NULL)  ;
-
-  void init(unsigned int width, unsigned int height,
-            int winx=-1, int winy=-1 ,
-            const char *title=NULL) ;
   
-  unsigned int getScreenDepth();
-  void getScreenSize(unsigned int &width, unsigned int &height);
   void getImage(vpImage<vpRGBa> &I) ;
+  unsigned int getScreenDepth();
+  unsigned int getScreenHeight();
+  void getScreenSize(unsigned int &width, unsigned int &height);
+  unsigned int getScreenWidth();
+
+  void init(vpImage<unsigned char> &I, int winx=-1, int winy=-1, const std::string &title="") ;
+  void init(vpImage<vpRGBa> &I, int winx=-1, int winy=-1, const std::string &title="") ;
+  void init(unsigned int width, unsigned int height, int winx=-1, int winy=-1, const std::string &title="") ;
 
 protected:
-
-  void setFont( const char *font );
-  void setTitle(const char *title) ;
-  void setWindowPosition(int winx, int winy);
-
   void clearDisplay(const vpColor &color=vpColor::white) ;
 
   void closeDisplay() ;
 
-  void displayArrow(const vpImagePoint &ip1, 
-		    const vpImagePoint &ip2,
-		    const vpColor &color=vpColor::white,
-		    unsigned int w=4,unsigned int h=2,
-		    unsigned int thickness=1) ;
+  void displayArrow(const vpImagePoint &ip1, const vpImagePoint &ip2,
+                    const vpColor &color=vpColor::white, unsigned int w=4,unsigned int h=2,
+                    unsigned int thickness=1) ;
 
   void displayCharString(const vpImagePoint &ip, const char *text,
-			 const vpColor &color=vpColor::green) ;
+                         const vpColor &color=vpColor::green) ;
 
   void displayCircle(const vpImagePoint &center, unsigned int radius,
-		     const vpColor &color,
-		     bool fill = false,
-		     unsigned int thickness=1);
+                     const vpColor &color, bool fill = false, unsigned int thickness=1);
   void displayCross(const vpImagePoint &ip, unsigned int size,
-		    const vpColor &color, unsigned int thickness=1) ;
-  void displayDotLine(const vpImagePoint &ip1, 
-		      const vpImagePoint &ip2,
-		      const vpColor &color, unsigned int thickness=1) ;
+                    const vpColor &color, unsigned int thickness=1) ;
+  void displayDotLine(const vpImagePoint &ip1,
+                      const vpImagePoint &ip2, const vpColor &color, unsigned int thickness=1) ;
 
-  void displayImage(const vpImage<vpRGBa> &I) ;
   void displayImage(const vpImage<unsigned char> &I) ;
+  void displayImage(const vpImage<vpRGBa> &I) ;
   void displayImage(const unsigned char *I) ;
-  
+
   void displayImageROI(const vpImage<unsigned char> &I,const vpImagePoint &iP, const unsigned int width, const unsigned int height);
   void displayImageROI(const vpImage<vpRGBa> &I,const vpImagePoint &iP, const unsigned int width, const unsigned int height);
 
-  void displayLine(const vpImagePoint &ip1, 
-		   const vpImagePoint &ip2,
-		   const vpColor &color, unsigned int thickness=1) ;
-  void displayPoint(const vpImagePoint &ip, const vpColor &color) ;
+  void displayLine(const vpImagePoint &ip1, const vpImagePoint &ip2,
+                   const vpColor &color, unsigned int thickness=1) ;
+  void displayPoint(const vpImagePoint &ip, const vpColor &color, unsigned int thickness=1) ;
 
-  void displayRectangle(const vpImagePoint &topLeft,
-			unsigned int width, unsigned int height,
-			const vpColor &color, bool fill = false,
-			unsigned int thickness=1) ;
-  void displayRectangle(const vpImagePoint &topLeft,
-			const vpImagePoint &bottomRight,
-			const vpColor &color, bool fill = false,
-			unsigned int thickness=1) ;
-  void displayRectangle(const vpRect &rectangle,
-			const vpColor &color, bool fill = false,
-			unsigned int thickness=1) ;
+  void displayRectangle(const vpImagePoint &topLeft, unsigned int width, unsigned int height,
+                        const vpColor &color, bool fill = false, unsigned int thickness=1) ;
+  void displayRectangle(const vpImagePoint &topLeft, const vpImagePoint &bottomRight,
+                        const vpColor &color, bool fill = false, unsigned int thickness=1) ;
+  void displayRectangle(const vpRect &rectangle, const vpColor &color, bool fill = false,
+                        unsigned int thickness=1) ;
 
   void flushDisplay() ;
   void flushDisplayROI(const vpImagePoint &iP, const unsigned int width, const unsigned int height);
 
   bool getClick(bool blocking=true) ;
   bool getClick(vpImagePoint &ip, bool blocking=true);
-  bool getClick(vpImagePoint &ip,
-		vpMouseButton::vpMouseButtonType& button,
-		bool blocking=true) ;
-  bool getClickUp(vpImagePoint &ip,
-		  vpMouseButton::vpMouseButtonType& button,
-		  bool blocking=true);
+  bool getClick(vpImagePoint &ip, vpMouseButton::vpMouseButtonType& button, bool blocking=true) ;
+  bool getClickUp(vpImagePoint &ip, vpMouseButton::vpMouseButtonType& button, bool blocking=true);
 
   bool getKeyboardEvent(bool blocking=true);
-  bool getKeyboardEvent(char *string, bool blocking=true);
+  bool getKeyboardEvent(std::string &key, bool blocking=true);
 
   int getMsb(unsigned int u32val);
   bool getPointerMotionEvent (vpImagePoint &ip);
   bool getPointerPosition (vpImagePoint &ip);
 
-  inline  unsigned int getWidth() const  { return width ; }
-  inline  unsigned int getHeight() const { return height ; }
-
-
+  void setFont(const std::string &font);
+  void setTitle(const std::string &title) ;
+  void setWindowPosition(int winx, int winy);
 } ; 
 
-
 #endif
 #endif
