@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -63,6 +63,23 @@
   \brief Class that enables to manipulate easily a video file or a sequence of
   images. As it inherits from the vpFrameGrabber Class, it can be used like an
   other frame grabber class.
+
+  This class has its own implementation to read a sequence of PGM and PPM images.
+
+  This class may benefit from optional 3rd parties:
+  - libpng: If installed this optional 3rd party is used to read a sequence of PNG images.
+    Installation instructions are provided here https://visp.inria.fr/3rd_png.
+  - libjpeg: If installed this optional 3rd party is used to read a sequence of JPEG images.
+    Installation instructions are provided here https://visp.inria.fr/3rd_jpeg.
+  - OpenCV: If installed this optional 3rd party is used to read a sequence of images
+    where images could be in TIFF, BMP, DIB, PBM, RASTER, JPEG2000 format. If libpng or
+    libjpeg is not installed, OpenCV is also used to consider these image formats. OpenCV
+    allows also to consider AVI, MPEG, MPEG4, MOV, OGV, WMV, FLV, MKV video formats.
+    Installation instructions are provided here https://visp.inria.fr/3rd_opencv.
+  - ffmpeg: If installed and enabled this optional 3rd party is used to read
+    AVI, MPEG, MPEG4, MOV, OGV, WMV, FLV, MKV video formats. It means that if OpenCV is
+    also installed, that OpenCV is not used to read a video. Installation instructions
+    are provided here https://visp.inria.fr/3rd_ffmpeg.
   
   The following example available in tutorial-video-reader.cpp shows how this
   class is really easy to use. It enables to read a video file named video.mpeg.
@@ -74,8 +91,6 @@
   the getFrame() method to position the reader in the video and then use the
   acquire() method to get the following frames one by one.
   \code
-#include <visp3/core/vpImage.h>
-#include <visp3/core/vpRGBa.h>
 #include <visp3/io/vpVideoReader.h>
 
 int main()
@@ -109,8 +124,6 @@ int main()
   match the first and image images of the sequence.
 
   \code
-#include <visp3/core/vpImage.h>
-#include <visp3/core/vpRGBa.h>
 #include <visp3/io/vpVideoReader.h>
 
 int main()
@@ -134,8 +147,6 @@ int main()
   
   Note that it is also possible to access to a specific frame using getFrame().
   \code
-#include <visp3/core/vpImage.h>
-#include <visp3/core/vpRGBa.h>
 #include <visp3/io/vpVideoReader.h>
 
 int main()
@@ -277,6 +288,9 @@ class VISP_EXPORT vpVideoReader : public vpFrameGrabber
     void open (vpImage< vpRGBa > &I);
     void open (vpImage< unsigned char > &I);
 
+    vpVideoReader & operator>>(vpImage<unsigned char> &I);
+    vpVideoReader & operator>>(vpImage<vpRGBa> &I);
+
     /*!
       Reset the frame counter and sets it to the first image index.
 
