@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -197,32 +197,31 @@ void
 vpImageSimulator::getImage(vpImage<unsigned char> &I, 
 			   const vpCameraParameters &cam)
 {
-  int nb_point_dessine = 0;
   if (setBackgroundTexture)
-      // The Ig has been set to a previously defined background texture
-      I = Ig;
+    // The Ig has been set to a previously defined background texture
+    I = Ig;
   else
+  {
+    if (cleanPrevImage)
     {
-      if (cleanPrevImage)
+      unsigned char col = (unsigned char) (0.2126 * bgColor.R
+                                           + 0.7152 * bgColor.G + 0.0722 * bgColor.B);
+      for (unsigned int i = 0; i < I.getHeight(); i++)
+      {
+        for (unsigned int j = 0; j < I.getWidth(); j++)
         {
-          unsigned char col = (unsigned char) (0.2126 * bgColor.R
-              + 0.7152 * bgColor.G + 0.0722 * bgColor.B);
-          for (unsigned int i = 0; i < I.getHeight(); i++)
-            {
-              for (unsigned int j = 0; j < I.getWidth(); j++)
-                {
-                  I[i][j] = col;
-                }
-            }
+          I[i][j] = col;
         }
+      }
     }
+  }
 
   if(visible)
   {
     if(!needClipping)
-        getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
     else
-        getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
     
     double top = rect.getTop();
     double bottom = rect.getBottom();
@@ -232,34 +231,35 @@ vpImageSimulator::getImage(vpImage<unsigned char> &I,
     unsigned char *bitmap = I.bitmap;
     unsigned int width = I.getWidth();
     vpImagePoint ip;
+    int nb_point_dessine = 0;
 
     for (unsigned int i = (unsigned int)top; i < (unsigned int)bottom; i++)
     {
       for (unsigned int j = (unsigned int)left; j < (unsigned int)right; j++)
       {
         double x=0,y=0;
-	ip.set_ij(i,j);
+        ip.set_ij(i,j);
         vpPixelMeterConversion::convertPoint(cam,ip, x,y);
-	ip.set_ij(y,x);
-	if (colorI == GRAY_SCALED)
-	{
-	  unsigned char Ipixelplan = 0;
-	  if(getPixel(ip,Ipixelplan))
-	  {
-	    *(bitmap+i*width+j)=Ipixelplan;
-	    nb_point_dessine++;
-	  }
-	}
-	else if (colorI == COLORED)
-	{
-	  vpRGBa Ipixelplan;
-	  if(getPixel(ip,Ipixelplan))
-	  {
-	    unsigned char pixelgrey = (unsigned char)(0.2126 * Ipixelplan.R + 0.7152 * Ipixelplan.G + 0.0722 * Ipixelplan.B);
-	    *(bitmap+i*width+j)=pixelgrey;
-	    nb_point_dessine++;
-	  }
-	}
+        ip.set_ij(y,x);
+        if (colorI == GRAY_SCALED)
+        {
+          unsigned char Ipixelplan = 0;
+          if(getPixel(ip,Ipixelplan))
+          {
+            *(bitmap+i*width+j)=Ipixelplan;
+            nb_point_dessine++;
+          }
+        }
+        else if (colorI == COLORED)
+        {
+          vpRGBa Ipixelplan;
+          if(getPixel(ip,Ipixelplan))
+          {
+            unsigned char pixelgrey = (unsigned char)(0.2126 * Ipixelplan.R + 0.7152 * Ipixelplan.G + 0.0722 * Ipixelplan.B);
+            *(bitmap+i*width+j)=pixelgrey;
+            nb_point_dessine++;
+          }
+        }
       }
     }
   }
@@ -278,7 +278,6 @@ vpImageSimulator::getImage(vpImage<unsigned char> &I,
 			  vpImage<unsigned char> &Isrc,
 			  const vpCameraParameters &cam)
 {
-  int nb_point_dessine = 0;
   if (cleanPrevImage)
   {
     unsigned char col = (unsigned char)(0.2126 * bgColor.R + 0.7152 * bgColor.G + 0.0722 * bgColor.B);
@@ -286,16 +285,16 @@ vpImageSimulator::getImage(vpImage<unsigned char> &I,
     {
       for (unsigned int j = 0; j < I.getWidth(); j++)
       {
-	I[i][j] = col;
+        I[i][j] = col;
       }
     }
   }
   if(visible)
   {
     if(!needClipping)
-        getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
     else
-        getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
 
     double top = rect.getTop();
     double bottom = rect.getBottom();
@@ -305,21 +304,22 @@ vpImageSimulator::getImage(vpImage<unsigned char> &I,
     unsigned char *bitmap = I.bitmap;
     unsigned int width = I.getWidth();
     vpImagePoint ip;
+    int nb_point_dessine = 0;
 
     for (unsigned int i = (unsigned int)top; i < (unsigned int)bottom; i++)
     {
       for (unsigned int j = (unsigned int)left; j < (unsigned int)right; j++)
       {
         double x=0,y=0;
-	ip.set_ij(i,j);
+        ip.set_ij(i,j);
         vpPixelMeterConversion::convertPoint(cam,ip, x,y);
-	ip.set_ij(y,x);
-	unsigned char Ipixelplan = 0;
-	if(getPixel(Isrc,ip,Ipixelplan))
-	{
-	  *(bitmap+i*width+j)=Ipixelplan;
-	  nb_point_dessine++;
-	}
+        ip.set_ij(y,x);
+        unsigned char Ipixelplan = 0;
+        if(getPixel(Isrc,ip,Ipixelplan))
+        {
+          *(bitmap+i*width+j)=Ipixelplan;
+          nb_point_dessine++;
+        }
       }
     }
   }
@@ -341,7 +341,6 @@ vpImageSimulator::getImage(vpImage<unsigned char> &I,
   if (I.getWidth() != (unsigned int)zBuffer.getCols() || I.getHeight() != (unsigned int)zBuffer.getRows())
     throw (vpMatrixException(vpMatrixException::incorrectMatrixSizeError, " zBuffer must have the same size as the image I ! "));
   
-  int nb_point_dessine = 0;
   if (cleanPrevImage)
   {
     unsigned char col = (unsigned char)(0.2126 * bgColor.R + 0.7152 * bgColor.G + 0.0722 * bgColor.B);
@@ -349,16 +348,16 @@ vpImageSimulator::getImage(vpImage<unsigned char> &I,
     {
       for (unsigned int j = 0; j < I.getWidth(); j++)
       {
-	I[i][j] = col;
+        I[i][j] = col;
       }
     }
   }
   if(visible)
   {
     if(!needClipping)
-        getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
     else
-        getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
     
     double top = rect.getTop();
     double bottom = rect.getBottom();
@@ -368,42 +367,43 @@ vpImageSimulator::getImage(vpImage<unsigned char> &I,
     unsigned char *bitmap = I.bitmap;
     unsigned int width = I.getWidth();
     vpImagePoint ip;
-    
+    int nb_point_dessine = 0;
+
     for (unsigned int i = (unsigned int)top; i < (unsigned int)bottom; i++)
     {
       for (unsigned int j = (unsigned int)left; j < (unsigned int)right; j++)
       {
         double x=0,y=0;
-	ip.set_ij(i,j);
+        ip.set_ij(i,j);
         vpPixelMeterConversion::convertPoint(cam,ip, x,y);
-	ip.set_ij(y,x);
-	if (colorI == GRAY_SCALED)
-	{
-	  unsigned char Ipixelplan;
-	  if(getPixel(ip,Ipixelplan))
-	  {
-	    if (Xinter_optim[2] < zBuffer[i][j] || zBuffer[i][j] < 0)
-	    {
-	      *(bitmap+i*width+j)=Ipixelplan;
-	      nb_point_dessine++;
-	      zBuffer[i][j] = Xinter_optim[2];
-	    }
-	  }
-	}
-	else if (colorI == COLORED)
-	{
-	  vpRGBa Ipixelplan;
-	  if(getPixel(ip,Ipixelplan))
-	  {
-	    if (Xinter_optim[2] < zBuffer[i][j] || zBuffer[i][j] < 0)
-	    {
-	      unsigned char pixelgrey = (unsigned char)(0.2126 * Ipixelplan.R + 0.7152 * Ipixelplan.G + 0.0722 * Ipixelplan.B);
-	      *(bitmap+i*width+j)=pixelgrey;
-	      nb_point_dessine++;
-	      zBuffer[i][j] = Xinter_optim[2];
-	    }
-	  }
-	}
+        ip.set_ij(y,x);
+        if (colorI == GRAY_SCALED)
+        {
+          unsigned char Ipixelplan;
+          if(getPixel(ip,Ipixelplan))
+          {
+            if (Xinter_optim[2] < zBuffer[i][j] || zBuffer[i][j] < 0)
+            {
+              *(bitmap+i*width+j)=Ipixelplan;
+              nb_point_dessine++;
+              zBuffer[i][j] = Xinter_optim[2];
+            }
+          }
+        }
+        else if (colorI == COLORED)
+        {
+          vpRGBa Ipixelplan;
+          if(getPixel(ip,Ipixelplan))
+          {
+            if (Xinter_optim[2] < zBuffer[i][j] || zBuffer[i][j] < 0)
+            {
+              unsigned char pixelgrey = (unsigned char)(0.2126 * Ipixelplan.R + 0.7152 * Ipixelplan.G + 0.0722 * Ipixelplan.B);
+              *(bitmap+i*width+j)=pixelgrey;
+              nb_point_dessine++;
+              zBuffer[i][j] = Xinter_optim[2];
+            }
+          }
+        }
       }
     }
   }
@@ -418,14 +418,13 @@ vpImageSimulator::getImage(vpImage<unsigned char> &I,
 void
 vpImageSimulator::getImage(vpImage<vpRGBa> &I, const vpCameraParameters &cam)
 {
-  int nb_point_dessine = 0;
   if (cleanPrevImage)
   {
     for (unsigned int i = 0; i < I.getHeight(); i++)
     {
       for (unsigned int j = 0; j < I.getWidth(); j++)
       {
-	I[i][j] = bgColor;
+        I[i][j] = bgColor;
       }
     }
   }
@@ -433,9 +432,9 @@ vpImageSimulator::getImage(vpImage<vpRGBa> &I, const vpCameraParameters &cam)
   if(visible)
   {
     if(!needClipping)
-        getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
     else
-        getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
     
     double top = rect.getTop();
     double bottom = rect.getBottom();
@@ -445,37 +444,38 @@ vpImageSimulator::getImage(vpImage<vpRGBa> &I, const vpCameraParameters &cam)
     vpRGBa *bitmap = I.bitmap;
     unsigned int width = I.getWidth();
     vpImagePoint ip;
-    
+    int nb_point_dessine = 0;
+
     for (unsigned int i = (unsigned int)top; i < (unsigned int)bottom; i++)
     {
       for (unsigned int j = (unsigned int)left; j < (unsigned int)right; j++)
       {
         double x=0,y=0;
-	ip.set_ij(i,j);
+        ip.set_ij(i,j);
         vpPixelMeterConversion::convertPoint(cam,ip, x,y);
-	ip.set_ij(y,x);
-	if (colorI == GRAY_SCALED)
-	{
-	  unsigned char Ipixelplan;
-	  if(getPixel(ip,Ipixelplan))
-	  {
-	    vpRGBa pixelcolor;
-	    pixelcolor.R = Ipixelplan;
-	    pixelcolor.G = Ipixelplan;
-	    pixelcolor.B = Ipixelplan;
-	    *(bitmap+i*width+j) = pixelcolor;
-	    nb_point_dessine++;
-	  }
-	}
-	else if (colorI == COLORED)
-	{
-	  vpRGBa Ipixelplan;
-	  if(getPixel(ip,Ipixelplan))
-	  {
-	    *(bitmap+i*width+j) = Ipixelplan;
-	    nb_point_dessine++;
-	  }
-	}
+        ip.set_ij(y,x);
+        if (colorI == GRAY_SCALED)
+        {
+          unsigned char Ipixelplan;
+          if(getPixel(ip,Ipixelplan))
+          {
+            vpRGBa pixelcolor;
+            pixelcolor.R = Ipixelplan;
+            pixelcolor.G = Ipixelplan;
+            pixelcolor.B = Ipixelplan;
+            *(bitmap+i*width+j) = pixelcolor;
+            nb_point_dessine++;
+          }
+        }
+        else if (colorI == COLORED)
+        {
+          vpRGBa Ipixelplan;
+          if(getPixel(ip,Ipixelplan))
+          {
+            *(bitmap+i*width+j) = Ipixelplan;
+            nb_point_dessine++;
+          }
+        }
       }
     }
   }
@@ -493,14 +493,13 @@ void
 vpImageSimulator::getImage(vpImage<vpRGBa> &I, vpImage<vpRGBa> &Isrc, 
 			   const vpCameraParameters &cam)
 {
-  int nb_point_dessine = 0;
   if (cleanPrevImage)
   {
     for (unsigned int i = 0; i < I.getHeight(); i++)
     {
       for (unsigned int j = 0; j < I.getWidth(); j++)
       {
-	I[i][j] = bgColor;
+        I[i][j] = bgColor;
       }
     }
   }
@@ -508,9 +507,9 @@ vpImageSimulator::getImage(vpImage<vpRGBa> &I, vpImage<vpRGBa> &Isrc,
   if(visible)
   {
     if(!needClipping)
-        getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
     else
-        getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
     
     double top = rect.getTop();
     double bottom = rect.getBottom();
@@ -520,21 +519,22 @@ vpImageSimulator::getImage(vpImage<vpRGBa> &I, vpImage<vpRGBa> &Isrc,
     vpRGBa *bitmap = I.bitmap;
     unsigned int width = I.getWidth();
     vpImagePoint ip;
-    
+    int nb_point_dessine = 0;
+
     for (unsigned int i = (unsigned int)top; i < (unsigned int)bottom; i++)
     {
       for (unsigned int j = (unsigned int)left; j < (unsigned int)right; j++)
       {
         double x=0,y=0;
-	ip.set_ij(i,j);
+        ip.set_ij(i,j);
         vpPixelMeterConversion::convertPoint(cam,ip, x,y);
-	ip.set_ij(y,x);
-	vpRGBa Ipixelplan;
-	if(getPixel(Isrc,ip,Ipixelplan))
-	{
-	  *(bitmap+i*width+j) = Ipixelplan;
-	  nb_point_dessine++;
-	}
+        ip.set_ij(y,x);
+        vpRGBa Ipixelplan;
+        if(getPixel(Isrc,ip,Ipixelplan))
+        {
+          *(bitmap+i*width+j) = Ipixelplan;
+          nb_point_dessine++;
+        }
       }
     }
   }
@@ -556,23 +556,22 @@ vpImageSimulator::getImage(vpImage<vpRGBa> &I, const vpCameraParameters &cam,
   if (I.getWidth() != (unsigned int)zBuffer.getCols() || I.getHeight() != (unsigned int)zBuffer.getRows())
     throw (vpMatrixException(vpMatrixException::incorrectMatrixSizeError, " zBuffer must have the same size as the image I ! "));
   
-  int nb_point_dessine = 0;
   if (cleanPrevImage)
   {
     for (unsigned int i = 0; i < I.getHeight(); i++)
     {
       for (unsigned int j = 0; j < I.getWidth(); j++)
       {
-	I[i][j] = bgColor;
+        I[i][j] = bgColor;
       }
     }
   }
   if(visible)
   {
     if(!needClipping)
-        getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,pt,rect);
     else
-        getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
+      getRoi(I.getWidth(),I.getHeight(),cam,ptClipped,rect);
     
     double top = rect.getTop();
     double bottom = rect.getBottom();
@@ -582,45 +581,46 @@ vpImageSimulator::getImage(vpImage<vpRGBa> &I, const vpCameraParameters &cam,
     vpRGBa *bitmap = I.bitmap;
     unsigned int width = I.getWidth();
     vpImagePoint ip;
-    
+    int nb_point_dessine = 0;
+
     for (unsigned int i = (unsigned int)top; i < (unsigned int)bottom; i++)
     {
       for (unsigned int j = (unsigned int)left; j < (unsigned int)right; j++)
       {
         double x=0,y=0;
-	ip.set_ij(i,j);
+        ip.set_ij(i,j);
         vpPixelMeterConversion::convertPoint(cam,ip, x,y);
-	ip.set_ij(y,x);
-	if (colorI == GRAY_SCALED)
-	{
-	  unsigned char Ipixelplan;
-	  if(getPixel(ip,Ipixelplan))
-	  {
-	    if (Xinter_optim[2] < zBuffer[i][j] || zBuffer[i][j] < 0)
-	    {
-	      vpRGBa pixelcolor;
-	      pixelcolor.R = Ipixelplan;
-	      pixelcolor.G = Ipixelplan;
-	      pixelcolor.B = Ipixelplan;
-	      *(bitmap+i*width+j) = pixelcolor;
-	      nb_point_dessine++;
-	      zBuffer[i][j] = Xinter_optim[2];
-	    }
-	  }
-	}
-	else if (colorI == COLORED)
-	{
-	  vpRGBa Ipixelplan;
-	  if(getPixel(ip,Ipixelplan))
-	  {
-	    if (Xinter_optim[2] < zBuffer[i][j] || zBuffer[i][j] < 0)
-	    {
-	      *(bitmap+i*width+j) = Ipixelplan;
-	      nb_point_dessine++;
-	      zBuffer[i][j] = Xinter_optim[2];
-	    }
-	  }
-	}
+        ip.set_ij(y,x);
+        if (colorI == GRAY_SCALED)
+        {
+          unsigned char Ipixelplan;
+          if(getPixel(ip,Ipixelplan))
+          {
+            if (Xinter_optim[2] < zBuffer[i][j] || zBuffer[i][j] < 0)
+            {
+              vpRGBa pixelcolor;
+              pixelcolor.R = Ipixelplan;
+              pixelcolor.G = Ipixelplan;
+              pixelcolor.B = Ipixelplan;
+              *(bitmap+i*width+j) = pixelcolor;
+              nb_point_dessine++;
+              zBuffer[i][j] = Xinter_optim[2];
+            }
+          }
+        }
+        else if (colorI == COLORED)
+        {
+          vpRGBa Ipixelplan;
+          if(getPixel(ip,Ipixelplan))
+          {
+            if (Xinter_optim[2] < zBuffer[i][j] || zBuffer[i][j] < 0)
+            {
+              *(bitmap+i*width+j) = Ipixelplan;
+              nb_point_dessine++;
+              zBuffer[i][j] = Xinter_optim[2];
+            }
+          }
+        }
       }
     }
   }
@@ -1343,10 +1343,9 @@ vpImageSimulator::getPixel(const vpImagePoint &iP, unsigned char &Ipixelplan)
   //	base =  u:(X[1]-X[0]) et v:(X[3]-X[0])
   //ici j'ai considere que le plan est un rectangle => coordonnees sont simplement obtenu par un produit scalaire
   double u = 0, v = 0;
-  double diff = 0;
   for(unsigned int i = 0; i < 3; i++)
   {
-    diff = (Xinter_optim[i]-X0_2_optim[i]);
+    double diff = (Xinter_optim[i]-X0_2_optim[i]);
     u += diff*vbase_u_optim[i];
     v += diff*vbase_v_optim[i];
   }
@@ -1400,10 +1399,9 @@ vpImageSimulator::getPixel(vpImage<unsigned char> &Isrc,
   //	base =  u:(X[1]-X[0]) et v:(X[3]-X[0])
   //ici j'ai considere que le plan est un rectangle => coordonnees sont simplement obtenu par un produit scalaire
   double u = 0, v = 0;
-  double diff = 0;
   for(unsigned int i = 0; i < 3; i++)
   {
-    diff = (Xinter_optim[i]-X0_2_optim[i]);
+    double diff = (Xinter_optim[i]-X0_2_optim[i]);
     u += diff*vbase_u_optim[i];
     v += diff*vbase_v_optim[i];
   }
@@ -1456,10 +1454,9 @@ vpImageSimulator::getPixel(const vpImagePoint &iP, vpRGBa &Ipixelplan)
   //	base =  u:(X[1]-X[0]) et v:(X[3]-X[0])
   //ici j'ai considere que le plan est un rectangle => coordonnees sont simplement obtenu par un produit scalaire
   double u = 0, v = 0;
-  double diff = 0;
   for(unsigned int i = 0; i < 3; i++)
   {
-    diff = (Xinter_optim[i]-X0_2_optim[i]);
+    double diff = (Xinter_optim[i]-X0_2_optim[i]);
     u += diff*vbase_u_optim[i];
     v += diff*vbase_v_optim[i];
   }
@@ -1512,10 +1509,9 @@ vpImageSimulator::getPixel(vpImage<vpRGBa> &Isrc, const vpImagePoint &iP,
   //	base =  u:(X[1]-X[0]) et v:(X[3]-X[0])
   //ici j'ai considere que le plan est un rectangle => coordonnees sont simplement obtenu par un produit scalaire
   double u = 0, v = 0;
-  double diff = 0;
   for(unsigned int i = 0; i < 3; i++)
   {
-    diff = (Xinter_optim[i]-X0_2_optim[i]);
+    double diff = (Xinter_optim[i]-X0_2_optim[i]);
     u += diff*vbase_u_optim[i];
     v += diff*vbase_v_optim[i];
   }
