@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,76 +48,37 @@
 #include <visp3/core/vpMath.h>
 #include <visp3/core/vpXmlParserCamera.h>
 
-static const char *opt_viper650[] = {"CAMERA", "eMc_ROT_XYZ","eMc_TRANS_XYZ",
-                                     NULL};
+static const char *opt_viper650[] = {"CAMERA", "eMc_ROT_XYZ","eMc_TRANS_XYZ", NULL};
 
-#ifdef VISP_HAVE_ACCESS_TO_NAS
-const char * const vpViper650::CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper650/current/include/const_eMc_MarlinF033C_without_distortion_Viper650.cnf";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_eMc_MarlinF033C_without_distortion_Viper650.cnf";
-#endif
+#ifdef VISP_HAVE_VIPER650_DATA
+const std::string vpViper650::CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_eMc_MarlinF033C_without_distortion_Viper650.cnf");
 
-const char * const vpViper650::CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME
-#if defined(_WIN32) 
-= "Z:/robot/Viper650/current/include/const_eMc_MarlinF033C_with_distortion_Viper650.cnf";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_eMc_MarlinF033C_with_distortion_Viper650.cnf";
-#endif
+const std::string vpViper650::CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_eMc_MarlinF033C_with_distortion_Viper650.cnf");
 
-const char * const vpViper650::CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper650/current/include/const_eMc_PTGreyFlea2_without_distortion_Viper650.cnf";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_eMc_PTGreyFlea2_without_distortion_Viper650.cnf";
-#endif
+const std::string vpViper650::CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_eMc_PTGreyFlea2_without_distortion_Viper650.cnf");
 
-const char * const vpViper650::CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME
-#if defined(_WIN32) 
-= "Z:/robot/Viper650/current/include/const_eMc_PTGreyFlea2_with_distortion_Viper650.cnf";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_eMc_PTGreyFlea2_with_distortion_Viper650.cnf";
-#endif
+const std::string vpViper650::CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_eMc_PTGreyFlea2_with_distortion_Viper650.cnf");
 
-const char * const vpViper650::CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper650/current/include/const_eMc_schunk_gripper_without_distortion_Viper650.cnf";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_eMc_schunk_gripper_without_distortion_Viper650.cnf";
-#endif
+const std::string vpViper650::CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_eMc_schunk_gripper_without_distortion_Viper650.cnf");
 
-const char * const vpViper650::CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper650/current/include/const_eMc_schunk_gripper_with_distortion_Viper650.cnf";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_eMc_schunk_gripper_with_distortion_Viper650.cnf";
-#endif
+const std::string vpViper650::CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_eMc_schunk_gripper_with_distortion_Viper650.cnf");
 
-const char * const vpViper650::CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper650/current/include/const_eMc_generic_without_distortion_Viper650.cnf";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_eMc_generic_without_distortion_Viper650.cnf";
-#endif
+const std::string vpViper650::CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_eMc_generic_without_distortion_Viper650.cnf");
 
-const char * const vpViper650::CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper650/current/include/const_eMc_generic_with_distortion_Viper650.cnf";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_eMc_generic_with_distortion_Viper650.cnf";
-#endif
+const std::string vpViper650::CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_eMc_generic_with_distortion_Viper650.cnf");
 
+const std::string vpViper650::CONST_CAMERA_FILENAME =
+    std::string(VISP_VIPER650_DATA_PATH) + std::string("/include/const_camera_Viper650.xml");
 
-const char * const vpViper650::CONST_CAMERA_FILENAME
-#if defined(_WIN32) 
-= "Z:/robot/Viper650/current/include/const_camera_Viper650.xml";
-#else
-= "/udd/fspindle/robot/Viper650/current/include/const_camera_Viper650.xml";
-#endif
-
-
-#endif // VISP_HAVE_ACCESS_TO_NAS
+#endif // VISP_HAVE_VIPER650_DATA
 
 const char * const vpViper650::CONST_MARLIN_F033C_CAMERA_NAME = "Marlin-F033C-12mm";
 const char * const vpViper650::CONST_PTGREY_FLEA2_CAMERA_NAME = "PTGrey-Flea2-6mm";
@@ -183,16 +144,14 @@ vpViper650::init (void)
   extrinsic parameters.
 
 */
-#ifdef VISP_HAVE_ACCESS_TO_NAS
 void
-vpViper650::init (const char *camera_extrinsic_parameters)
+vpViper650::init (const std::string &camera_extrinsic_parameters)
 {
   //vpTRACE ("Parse camera file \""%s\"".", camera_filename);
   this->parseConfigFile (camera_extrinsic_parameters);
 
   return ;
 }
-#endif
 
 /*!
 
@@ -202,7 +161,7 @@ vpViper650::init (const char *camera_extrinsic_parameters)
   parameters depend on the camera and projection model in use and are
   loaded from predefined files or parameters.
 
-  \warning If the macro VISP_HAVE_ACCESS_TO_NAS is defined in vpConfig.h
+  \warning If the macro VISP_HAVE_VIPER650_DATA is defined in vpConfig.h
   this function reads the camera extrinsic parameters from the file
   corresponding to the specified camera type and projection type.
   Otherwise corresponding default parameters are loaded.
@@ -222,29 +181,17 @@ vpViper650::init (vpViper650::vpToolType tool,
   
   this->projModel = proj_model;
   
-#ifdef VISP_HAVE_ACCESS_TO_NAS
+#ifdef VISP_HAVE_VIPER650_DATA
   // Read the robot parameters from files
-  char filename_eMc [FILENAME_MAX];
+  std::string filename_eMc;
   switch (tool) {
   case vpViper650::TOOL_MARLIN_F033C_CAMERA: {
     switch(projModel) {
     case vpCameraParameters::perspectiveProjWithoutDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::perspectiveProjWithDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME;
       break;
     }
     break;
@@ -252,22 +199,10 @@ vpViper650::init (vpViper650::vpToolType tool,
   case vpViper650::TOOL_PTGREY_FLEA2_CAMERA: {
     switch(projModel) {
     case vpCameraParameters::perspectiveProjWithoutDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::perspectiveProjWithDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME;
       break;
     }
     break;
@@ -275,22 +210,10 @@ vpViper650::init (vpViper650::vpToolType tool,
   case vpViper650::TOOL_SCHUNK_GRIPPER_CAMERA: {
     switch(projModel) {
     case vpCameraParameters::perspectiveProjWithoutDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::perspectiveProjWithDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME;
       break;
     }
     break;
@@ -298,32 +221,19 @@ vpViper650::init (vpViper650::vpToolType tool,
   case vpViper650::TOOL_GENERIC_CAMERA: {
     switch(projModel) {
     case vpCameraParameters::perspectiveProjWithoutDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::perspectiveProjWithDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME;
       break;
     }
     break;
   }
   case vpViper650::TOOL_CUSTOM: {
-    vpERROR_TRACE ("No predefined file available for a custom tool"
-                   "You should use init(vpViper650::vpToolType, const std::string&) or"
-                   "init(vpViper650::vpToolType, const vpHomogeneousMatrix&) instead");
-    throw vpRobotException (vpRobotException::badValue, "No predefined file available for a custom tool");
-    break;
+    throw vpRobotException (vpRobotException::badValue,
+                            "No predefined file available for a custom tool"
+                            "You should use init(vpViper650::vpToolType, const std::string&) or"
+                            "init(vpViper650::vpToolType, const vpHomogeneousMatrix&) instead");
   }
   default: {
     vpERROR_TRACE ("This error should not occur!");
@@ -341,7 +251,7 @@ vpViper650::init (vpViper650::vpToolType tool,
   
   this->init (filename_eMc);
 
-#else // VISP_HAVE_ACCESS_TO_NAS
+#else // VISP_HAVE_VIPER650_DATA
 
   // Use here default values of the robot constant parameters.
   switch (tool) {
@@ -404,16 +314,15 @@ vpViper650::init (vpViper650::vpToolType tool,
     break;
   }
   case vpViper650::TOOL_CUSTOM: {
-    vpERROR_TRACE ("No predefined parameters available for a custom tool"
-                   "You should use init(vpViper650::vpToolType, const std::string&) or"
-                   "init(vpViper650::vpToolType, const vpHomogeneousMatrix&) instead");
-    throw vpRobotException (vpRobotException::badValue, "No predefined parameters available for a custom tool");
-    break;
+    throw vpRobotException (vpRobotException::badValue,
+                            "No predefined parameters available for a custom tool"
+                            "You should use init(vpViper650::vpToolType, const std::string&) or"
+                            "init(vpViper650::vpToolType, const vpHomogeneousMatrix&) instead");
   }
   }
   vpRotationMatrix eRc(erc);
   this->eMc.buildFrom(etc, eRc);
-#endif // VISP_HAVE_ACCESS_TO_NAS
+#endif // VISP_HAVE_VIPER650_DATA
 
   setToolType(tool);
   return ;
@@ -445,13 +354,12 @@ eMc_ROT_XYZ 10.0 -90.0 20.0
 eMc_TRANS_XYZ  0.05 0.01 0.06
     \endcode
 
-  \sa init(vpViper650::vpToolType,
-  vpCameraParameters::vpCameraParametersProjType),
+  \sa init(vpViper650::vpToolType, vpCameraParameters::vpCameraParametersProjType),
   init(vpViper650::vpToolType, const vpHomogeneousMatrix&)
 */
 void
-vpViper650::init (vpViper650::vpToolType tool,
-                  const std::string &filename)
+vpViper650::init(vpViper650::vpToolType tool,
+                 const std::string &filename)
 {
     this->setToolType(tool);
     this->parseConfigFile(filename.c_str());
@@ -467,14 +375,13 @@ vpViper650::init (vpViper650::vpToolType tool,
   \param eMc_ : Homogeneous matrix representation of the transformation
   between the end-effector frame and the tool frame.
 
-  \sa init(vpViper650::vpToolType,
-  vpCameraParameters::vpCameraParametersProjType),
+  \sa init(vpViper650::vpToolType, vpCameraParameters::vpCameraParametersProjType),
   init(vpViper650::vpToolType, const std::string&)
 
 */
 void
-vpViper650::init (vpViper650::vpToolType tool,
-                  const vpHomogeneousMatrix &eMc_)
+vpViper650::init(vpViper650::vpToolType tool,
+                 const vpHomogeneousMatrix &eMc_)
 {
     this->setToolType(tool);
     this->set_eMc(eMc_);
@@ -489,7 +396,7 @@ vpViper650::init (vpViper650::vpToolType tool,
 
 */
 void
-vpViper650::parseConfigFile (const char * filename)
+vpViper650::parseConfigFile (const std::string &filename)
 {
   size_t            dim;
   int               code;
@@ -502,32 +409,30 @@ vpViper650::parseConfigFile (const char * filename)
   bool get_rot_eMc = false;
   bool get_trans_eMc = false;
 
-  //vpTRACE("Read the config file for constant parameters %s.", filename);
-  if ((fdtask = fopen(filename, "r" )) == NULL)
-  {
-    vpERROR_TRACE ("Impossible to read the config file %s.",
-                   filename);
+  //vpTRACE("Read the config file for constant parameters %s.", filename.c_str());
+  if ((fdtask = fopen(filename.c_str(), "r" )) == NULL) {
     throw vpRobotException (vpRobotException::readingParametersError,
-                            "Impossible to read the config file.");
+                            "Impossible to read the config file %s.", filename.c_str());
   }
 
   while (fgets(Ligne, FILENAME_MAX, fdtask) != NULL) {
     numLn ++;
     if ('#' == Ligne[0]) { continue; }
-    if (sscanf(Ligne, "%s", namoption) != 1) {
-      fclose (fdtask);
-      throw(vpException(vpException::badValue,
-                        "Cannot parse configuration file %s to retrieve option name"));
+    {
+      std::stringstream ss(Ligne);
+      ss >> namoption;
+
+      if (ss.fail()) {
+        fclose (fdtask);
+        throw(vpException(vpException::badValue,
+                          "Cannot parse configuration file %s to retrieve option name"));
+      }
     }
 
     dim = strlen(namoption);
 
-    for (code = 0;
-         NULL != opt_viper650[code];
-         ++ code)
-    {
-      if (strncmp(opt_viper650[code], namoption, dim) == 0)
-      {
+    for (code = 0; NULL != opt_viper650[code]; ++ code)  {
+      if (strncmp(opt_viper650[code], namoption, dim) == 0) {
         break;
       }
     }
@@ -536,12 +441,13 @@ vpViper650::parseConfigFile (const char * filename)
     case 0:
       break; // Nothing to do: camera name
 
-    case 1:
-      if (sscanf(Ligne, "%s %lf %lf %lf", namoption,
-                 &rot_eMc[0], &rot_eMc[1], &rot_eMc[2]) != 4) {
+    case 1: {
+      std::stringstream ss(Ligne);
+      ss >> namoption >> rot_eMc[0] >> rot_eMc[1] >> rot_eMc[2];
+      if (ss.fail()) {
         fclose (fdtask);
         throw(vpException(vpException::badValue,
-                          "Cannot parse configuration file %s to retrieve translation"));
+                          "Cannot parse configuration file %s to retrieve rotation", filename.c_str()));
       }
 
       // Convert rotation from degrees to radians
@@ -550,20 +456,23 @@ vpViper650::parseConfigFile (const char * filename)
       rot_eMc[2] *= M_PI / 180.0;
       get_rot_eMc = true;
       break;
+    }
 
-    case 2:
-      if (sscanf(Ligne, "%s %lf %lf %lf", namoption,
-                 &trans_eMc[0], &trans_eMc[1], &trans_eMc[2]) != 4) {
+    case 2: {
+      std::stringstream ss(Ligne);
+      ss >> namoption >> trans_eMc[0] >> trans_eMc[1] >> trans_eMc[2];
+      if (ss.fail()) {
         fclose (fdtask);
         throw(vpException(vpException::badValue,
-                          "Cannot parse configuration file %s to retrieve rotation"));
+                          "Cannot parse configuration file %s to retrieve translation", filename.c_str()));
       }
       get_trans_eMc = true;
       break;
+    }
 
     default:
       vpERROR_TRACE ("Bad configuration file %s  "
-                     "ligne #%d.", filename, numLn);
+                     "line #%d.", filename.c_str(), numLn);
     } /* SWITCH */
   } /* WHILE */
 
@@ -574,10 +483,8 @@ vpViper650::parseConfigFile (const char * filename)
     this->set_eMc(trans_eMc,rot_eMc);
   }
   else {
-    vpERROR_TRACE ("Could not read translation and rotation parameters from config file %s.",
-                     filename);
     throw vpRobotException (vpRobotException::readingParametersError,
-                              "Could not read translation and rotation parameters from config file ");
+                            "Could not read translation and rotation parameters from config file %s", filename.c_str());
   }
 
   return;
@@ -592,14 +499,12 @@ vpViper650::parseConfigFile (const char * filename)
   parameters. If XML is detected by ViSP, VISP_HAVE_XML2 macro is
   defined in include/visp3/core/vpConfig.h file.
 
-  \warning Thid method needs also an access to the file located on
-  Inria's NAS server and containing the camera parameters in XML
-  format. This access is available if VISP_HAVE_ACCESS_TO_NAS macro is
-  defined in include/visp3/core/vpConfig.h file.
+  \warning Thid method needs also an access to the files containing the
+  camera parameters in XML format. This access is available if
+  VISP_HAVE_VIPER650_DATA macro is defined in include/visp3/core/vpConfig.h file.
 
-  - If VISP_HAVE_ACCESS_TO_NAS and VISP_HAVE_XML2 macros are defined,
-  this method gets the camera parameters from
-  /udd/fspindle/robot/Viper650/current/include/const_camera_Viper650.xml
+  - If VISP_HAVE_VIPER650_DATA and VISP_HAVE_XML2 macros are defined,
+  this method gets the camera parameters from const_camera_Viper650.xml
   config file.
 
   - If these two macros are not defined, this method set the camera parameters
@@ -640,7 +545,7 @@ int main()
   // Get the intrinsic camera parameters depending on the image size
   // Camera parameters are read from
   // /udd/fspindle/robot/Viper650/current/include/const_camera_Viper650.xml
-  // if VISP_HAVE_ACCESS_TO_NAS and VISP_HAVE_XML2 macros are defined
+  // if VISP_HAVE_VIPER650_DATA and VISP_HAVE_XML2 macros are defined
   // in vpConfig.h file
   try {
     robot.getCameraParameters (cam, I.getWidth(), I.getHeight());
@@ -661,7 +566,7 @@ vpViper650::getCameraParameters (vpCameraParameters &cam,
                                  const unsigned int &image_width,
                                  const unsigned int &image_height) const
 {
-#if defined(VISP_HAVE_XML2) && defined (VISP_HAVE_ACCESS_TO_NAS)
+#if defined(VISP_HAVE_XML2) && defined (VISP_HAVE_VIPER650_DATA)
   vpXmlParserCamera parser;
   switch (getToolType()) {
   case vpViper650::TOOL_MARLIN_F033C_CAMERA: {
@@ -725,9 +630,8 @@ vpViper650::getCameraParameters (vpCameraParameters &cam,
     break;
   }
   case vpViper650::TOOL_CUSTOM: {
-    vpERROR_TRACE ("No intrinsic parameters available for a custom tool");
-    throw vpRobotException (vpRobotException::badValue, "No intrinsic parameters available for a custom tool");
-    break;
+    throw vpRobotException (vpRobotException::badValue,
+                            "No intrinsic parameters available for a custom tool");
   }
   default: {
     vpERROR_TRACE ("This error should not occur!");
@@ -741,7 +645,6 @@ vpViper650::getCameraParameters (vpCameraParameters &cam,
     //        "fonction init(camera).");
     throw vpRobotException (vpRobotException::readingParametersError,
                             "Impossible to read the camera parameters.");
-    break;
   }
   }
 #else
@@ -812,9 +715,8 @@ vpViper650::getCameraParameters (vpCameraParameters &cam,
     break;
   }
   case vpViper650::TOOL_CUSTOM: {
-    vpERROR_TRACE ("No intrinsic parameters available for a custom tool");
-    throw vpRobotException (vpRobotException::badValue, "No intrinsic parameters available for a custom tool");
-    break;
+    throw vpRobotException (vpRobotException::badValue,
+                            "No intrinsic parameters available for a custom tool");
   }
   default:
     vpERROR_TRACE ("This error should not occur!");
@@ -834,14 +736,12 @@ vpViper650::getCameraParameters (vpCameraParameters &cam,
   parameters. If XML is detected by ViSP, VISP_HAVE_XML2 macro is
   defined in include/visp3/core/vpConfig.h file.
 
-  \warning Thid method needs also an access to the file located on
-  Inria's NAS server and containing the camera parameters in XML
-  format. This access is available if VISP_HAVE_ACCESS_TO_NAS macro is
-  defined in include/visp3/core/vpConfig.h file.
+  \warning Thid method needs also an access to the files containing the
+  camera parameters in XML format. This access is available if
+  VISP_HAVE_VIPER650_DATA macro is defined in include/visp3/core/vpConfig.h file.
 
-  - If VISP_HAVE_ACCESS_TO_NAS and VISP_HAVE_XML2 macros are defined,
-  this method gets the camera parameters from
-  /udd/fspindle/robot/Viper650/current/include/const_camera_Viper650.xml
+  - If VISP_HAVE_VIPER650_DATA and VISP_HAVE_XML2 macros are defined,
+  this method gets the camera parameters from const_camera_Viper650.xml
   config file.
 
   - If these two macros are not defined, this method set the camera parameters
@@ -903,14 +803,12 @@ vpViper650::getCameraParameters (vpCameraParameters &cam,
   parameters. If XML is detected by ViSP, VISP_HAVE_XML2 macro is
   defined in include/visp3/core/vpConfig.h file.
 
-  \warning Thid method needs also an access to the file located on
-  Inria's NAS server and containing the camera parameters in XML
-  format. This access is available if VISP_HAVE_ACCESS_TO_NAS macro is
-  defined in include/visp3/core/vpConfig.h file.
+  \warning Thid method needs also an access to the files containing the camera
+  parameters in XML format. This access is available if VISP_HAVE_VIPER650_DATA
+  macro is defined in include/visp3/core/vpConfig.h file.
 
-  - If VISP_HAVE_ACCESS_TO_NAS and VISP_HAVE_XML2 macros are defined,
-  this method gets the camera parameters from
-  /udd/fspindle/robot/Viper650/current/include/const_camera_Viper650.xml
+  - If VISP_HAVE_VIPER650_DATA and VISP_HAVE_XML2 macros are defined,
+  this method gets the camera parameters from const_camera_Viper650.xml
   config file.
 
   - If these two macros are not defined, this method set the camera parameters
