@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,76 +48,38 @@
 #include <visp3/core/vpMath.h>
 #include <visp3/core/vpXmlParserCamera.h>
 
-#ifdef VISP_HAVE_ACCESS_TO_NAS
 static const char *opt_viper850[] = {"CAMERA", "eMc_ROT_XYZ","eMc_TRANS_XYZ",
                                      NULL};
 
-const char * const vpViper850::CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper850/current/include/const_eMc_MarlinF033C_without_distortion_Viper850.cnf";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_eMc_MarlinF033C_without_distortion_Viper850.cnf";
-#endif
+#ifdef VISP_HAVE_VIPER850_DATA
+const std::string vpViper850::CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_eMc_MarlinF033C_without_distortion_Viper850.cnf");
 
-const char * const vpViper850::CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME
-#if defined(_WIN32) 
-= "Z:/robot/Viper850/current/include/const_eMc_MarlinF033C_with_distortion_Viper850.cnf";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_eMc_MarlinF033C_with_distortion_Viper850.cnf";
-#endif
+const std::string vpViper850::CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_eMc_MarlinF033C_with_distortion_Viper850.cnf");
 
-const char * const vpViper850::CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper850/current/include/const_eMc_PTGreyFlea2_without_distortion_Viper850.cnf";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_eMc_PTGreyFlea2_without_distortion_Viper850.cnf";
-#endif
+const std::string vpViper850::CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_eMc_PTGreyFlea2_without_distortion_Viper850.cnf");
 
-const char * const vpViper850::CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME
-#if defined(_WIN32) 
-= "Z:/robot/Viper850/current/include/const_eMc_PTGreyFlea2_with_distortion_Viper850.cnf";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_eMc_PTGreyFlea2_with_distortion_Viper850.cnf";
-#endif
+const std::string vpViper850::CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_eMc_PTGreyFlea2_with_distortion_Viper850.cnf");
 
-const char * const vpViper850::CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper850/current/include/const_eMc_schunk_gripper_without_distortion_Viper850.cnf";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_eMc_schunk_gripper_without_distortion_Viper850.cnf";
-#endif
+const std::string vpViper850::CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_eMc_schunk_gripper_without_distortion_Viper850.cnf");
 
-const char * const vpViper850::CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper850/current/include/const_eMc_schunk_gripper_with_distortion_Viper850.cnf";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_eMc_schunk_gripper_with_distortion_Viper850.cnf";
-#endif
+const std::string vpViper850::CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_eMc_schunk_gripper_with_distortion_Viper850.cnf");
 
-const char * const vpViper850::CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper850/current/include/const_eMc_generic_without_distortion_Viper850.cnf";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_eMc_generic_without_distortion_Viper850.cnf";
-#endif
+const std::string vpViper850::CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_eMc_generic_without_distortion_Viper850.cnf");
 
-const char * const vpViper850::CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME
-#if defined(_WIN32)
-= "Z:/robot/Viper850/current/include/const_eMc_generic_with_distortion_Viper850.cnf";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_eMc_generic_with_distortion_Viper850.cnf";
-#endif
+const std::string vpViper850::CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_eMc_generic_with_distortion_Viper850.cnf");
 
+const std::string vpViper850::CONST_CAMERA_FILENAME =
+    std::string(VISP_VIPER850_DATA_PATH) + std::string("/include/const_camera_Viper850.xml");
 
-const char * const vpViper850::CONST_CAMERA_FILENAME
-#if defined(_WIN32) 
-= "Z:/robot/Viper850/current/include/const_camera_Viper850.xml";
-#else
-= "/udd/fspindle/robot/Viper850/current/include/const_camera_Viper850.xml";
-#endif
-
-
-#endif // VISP_HAVE_ACCESS_TO_NAS
+#endif // VISP_HAVE_VIPER850_DATA
 
 const char * const vpViper850::CONST_MARLIN_F033C_CAMERA_NAME = "Marlin-F033C-12mm";
 const char * const vpViper850::CONST_PTGREY_FLEA2_CAMERA_NAME = "PTGrey-Flea2-6mm";
@@ -178,37 +140,41 @@ vpViper850::init (void)
 /*!
 
   Read files containing the constant parameters related to the robot
-  tools in order to set the end-effector to camera transformation.
-
-  \warning This function is only available if the macro
-  VISP_HAVE_ACCESS_TO_NAS is defined in vpConfig.h.
+  tools in order to set the end-effector to tool transformation.
 
   \param camera_extrinsic_parameters : Filename containing the camera
   extrinsic parameters.
 
 */
-#ifdef VISP_HAVE_ACCESS_TO_NAS
 void
-vpViper850::init (const char *camera_extrinsic_parameters)
+vpViper850::init (const std::string &camera_extrinsic_parameters)
 {
   //vpTRACE ("Parse camera file \""%s\"".", camera_filename);
   this->parseConfigFile (camera_extrinsic_parameters);
 
   return ;
 }
-#endif
 
 /*!
 
   Set the constant parameters related to the robot kinematics and to
   the end-effector to camera transformation (\f$^e{\bf M}c\f$)
   corresponding to the camera extrinsic parameters. These last
-  parameters depend on the camera and projection model in use.
+  parameters depend on the camera and projection model in use and are
+  loaded from predefined files or parameters.
+
+  \warning If the macro VISP_HAVE_VIPER850_DATA is defined in vpConfig.h
+  this function reads the camera extrinsic parameters from the file
+  corresponding to the specified camera type and projection type.
+  Otherwise corresponding default parameters are loaded.
 
   \param tool : Camera in use.
 
   \param proj_model : Projection model of the camera.
 
+  \sa init(vpViper850::vpToolType, const std::string&),
+  init(vpViper850::vpToolType, const vpHomogeneousMatrix&)
+
 */
 void
 vpViper850::init (vpViper850::vpToolType tool,
@@ -217,29 +183,17 @@ vpViper850::init (vpViper850::vpToolType tool,
   
   this->projModel = proj_model;
   
-#ifdef VISP_HAVE_ACCESS_TO_NAS
+#ifdef VISP_HAVE_VIPER850_DATA
   // Read the robot parameters from files
-  char filename_eMc [FILENAME_MAX];
+  std::string filename_eMc;
   switch (tool) {
   case vpViper850::TOOL_MARLIN_F033C_CAMERA: {
     switch(projModel) {
     case vpCameraParameters::perspectiveProjWithoutDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_MARLIN_F033C_WITHOUT_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::perspectiveProjWithDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME;
       break;
     }
     break;
@@ -247,22 +201,10 @@ vpViper850::init (vpViper850::vpToolType tool,
   case vpViper850::TOOL_PTGREY_FLEA2_CAMERA: {
     switch(projModel) {
     case vpCameraParameters::perspectiveProjWithoutDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_PTGREY_FLEA2_WITHOUT_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::perspectiveProjWithDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME;
       break;
     }
     break;
@@ -270,22 +212,10 @@ vpViper850::init (vpViper850::vpToolType tool,
   case vpViper850::TOOL_SCHUNK_GRIPPER_CAMERA: {
     switch(projModel) {
     case vpCameraParameters::perspectiveProjWithoutDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_SCHUNK_GRIPPER_WITHOUT_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::perspectiveProjWithDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME;
       break;
     }
     break;
@@ -293,26 +223,20 @@ vpViper850::init (vpViper850::vpToolType tool,
   case vpViper850::TOOL_GENERIC_CAMERA: {
     switch(projModel) {
     case vpCameraParameters::perspectiveProjWithoutDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_GENERIC_WITHOUT_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::perspectiveProjWithDistortion :
-#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-      snprintf(filename_eMc, FILENAME_MAX, "%s",
-               CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME);
-#else // _WIN32
-      _snprintf(filename_eMc, FILENAME_MAX, "%s",
-                CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME);
-#endif
+        filename_eMc = CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME;
       break;
     }
     break;
   }
+  case vpViper850::TOOL_CUSTOM: {
+    throw vpRobotException (vpRobotException::badValue,
+                            "No predefined file available for a custom tool"
+                            "You should use init(vpViper850::vpToolType, const std::string&) or"
+                            "init(vpViper850::vpToolType, const vpHomogeneousMatrix&) instead");
+  }
   default: {
     vpERROR_TRACE ("This error should not occur!");
     //       vpERROR_TRACE ("Si elle survient malgre tout, c'est sans doute "
@@ -329,7 +253,7 @@ vpViper850::init (vpViper850::vpToolType tool,
   
   this->init (filename_eMc);
 
-#else // VISP_HAVE_ACCESS_TO_NAS
+#else // VISP_HAVE_VIPER850_DATA
 
   // Use here default values of the robot constant parameters.
   switch (tool) {
@@ -391,10 +315,16 @@ vpViper850::init (vpViper850::vpToolType tool,
     }
     break;
   }
+  case vpViper850::TOOL_CUSTOM: {
+    throw vpRobotException (vpRobotException::badValue,
+                            "No predefined parameters available for a custom tool"
+                            "You should use init(vpViper850::vpToolType, const std::string&) or"
+                            "init(vpViper850::vpToolType, const vpHomogeneousMatrix&) instead");
+  }
   }
   vpRotationMatrix eRc(erc);
   this->eMc.buildFrom(etc, eRc);
-#endif // VISP_HAVE_ACCESS_TO_NAS
+#endif // VISP_HAVE_VIPER850_DATA
 
   setToolType(tool);
   return ;
@@ -402,18 +332,71 @@ vpViper850::init (vpViper850::vpToolType tool,
 
 /*!
 
-  This function gets the robot constant parameters from a file.
+  Set the type of tool attached to the robot and transformation
+  between the end-effector and the tool (\f$^e{\bf M}c\f$).
+  This last parameter is loaded from a file.
 
-  \warning This function is only available if the macro
-  VISP_HAVE_ACCESS_TO_NAS is defined in vpConfig.h.
+  \param tool : Type of tool in use.
+
+  \param filename : Path of the configuration file containing the
+  transformation between the end-effector frame and the tool frame.
+
+  The configuration file should have the form below:
+
+  \code
+# Start with any number of consecutive lines
+# beginning with the symbol '#'
+#
+# The 3 following lines contain the name of the camera,
+# the rotation parameters of the geometric transformation
+# using the Euler angles in degrees with convention XYZ and
+# the translation parameters expressed in meters
+CAMERA CameraName
+eMc_ROT_XYZ 10.0 -90.0 20.0
+eMc_TRANS_XYZ  0.05 0.01 0.06
+    \endcode
+
+  \sa init(vpViper850::vpToolType, vpCameraParameters::vpCameraParametersProjType),
+  init(vpViper850::vpToolType, const vpHomogeneousMatrix&)
+*/
+void
+vpViper850::init(vpViper850::vpToolType tool, const std::string &filename)
+{
+  this->setToolType(tool);
+  this->parseConfigFile(filename.c_str());
+}
+
+/*!
+
+  Set the type of tool attached to the robot and the transformation
+  between the end-effector and the tool (\f$^e{\bf M}c\f$).
+
+  \param tool : Type of tool in use.
+
+  \param eMc_ : Homogeneous matrix representation of the transformation
+  between the end-effector frame and the tool frame.
+
+  \sa init(vpViper850::vpToolType, vpCameraParameters::vpCameraParametersProjType),
+  init(vpViper850::vpToolType, const std::string&)
+
+*/
+void
+vpViper850::init(vpViper850::vpToolType tool, const vpHomogeneousMatrix &eMc_)
+{
+  this->setToolType(tool);
+  this->set_eMc(eMc_);
+}
+
+/*!
+
+  This function gets the robot constant parameters from a file.
 
   \param filename : File name containing the robot constant
   parameters, like the hand-to-eye transformation.
 
 */
-#ifdef VISP_HAVE_ACCESS_TO_NAS
 void
-vpViper850::parseConfigFile (const char * filename)
+vpViper850::parseConfigFile (const std::string &filename)
 {
   size_t            dim;
   int               code;
@@ -421,36 +404,36 @@ vpViper850::parseConfigFile (const char * filename)
   char              namoption[100];
   FILE *            fdtask;
   int               numLn = 0;
-  double rot_eMc[3]; // rotation
-  double trans_eMc[3]; // translation
+  vpRxyzVector rot_eMc; // rotation
+  vpTranslationVector trans_eMc; // translation
   bool get_rot_eMc = false;
   bool get_trans_eMc = false;
 
-  //vpTRACE("Read the config file for constant parameters %s.", filename);
-  if ((fdtask = fopen(filename, "r" )) == NULL)
-  {
-    vpERROR_TRACE ("Impossible to read the config file %s.",
-                   filename);
+  //vpTRACE("Read the config file for constant parameters %s.", filename.c_str());
+  if ((fdtask = fopen(filename.c_str(), "r" )) == NULL) {
     throw vpRobotException (vpRobotException::readingParametersError,
-                            "Impossible to read the config file.");
+                            "Impossible to read the config file %s.", filename.c_str());
   }
 
+
   while (fgets(Ligne, FILENAME_MAX, fdtask) != NULL) {
     numLn ++;
     if ('#' == Ligne[0]) { continue; }
-    if (sscanf(Ligne, "%s", namoption) != 1) {
-      fclose (fdtask);
-      throw(vpException(vpException::badValue,
-                        "Cannot parse configuration file %s to retrieve option name"));
+    {
+      std::stringstream ss(Ligne);
+      ss >> namoption;
+
+      if (ss.fail()) {
+        fclose (fdtask);
+        throw(vpException(vpException::badValue,
+                          "Cannot parse configuration file %s to retrieve option name", filename.c_str()));
+      }
     }
+
     dim = strlen(namoption);
 
-    for (code = 0;
-         NULL != opt_viper850[code];
-         ++ code)
-    {
-      if (strncmp(opt_viper850[code], namoption, dim) == 0)
-      {
+    for (code = 0; NULL != opt_viper850[code]; ++ code)  {
+      if (strncmp(opt_viper850[code], namoption, dim) == 0) {
         break;
       }
     }
@@ -459,12 +442,13 @@ vpViper850::parseConfigFile (const char * filename)
     case 0:
       break; // Nothing to do: camera name
 
-    case 1:
-      if (sscanf(Ligne, "%s %lf %lf %lf", namoption,
-                 &rot_eMc[0], &rot_eMc[1], &rot_eMc[2]) != 4) {
+    case 1: {
+      std::stringstream ss(Ligne);
+      ss >> namoption >> rot_eMc[0] >> rot_eMc[1] >> rot_eMc[2];
+      if (ss.fail()) {
         fclose (fdtask);
         throw(vpException(vpException::badValue,
-                          "Cannot parse configuration file %s to retrieve translation"));
+                          "Cannot parse configuration file %s to retrieve rotation", filename.c_str()));
       }
 
       // Convert rotation from degrees to radians
@@ -473,20 +457,22 @@ vpViper850::parseConfigFile (const char * filename)
       rot_eMc[2] *= M_PI / 180.0;
       get_rot_eMc = true;
       break;
+    }
 
-    case 2:
-      if (sscanf(Ligne, "%s %lf %lf %lf", namoption,
-                 &trans_eMc[0], &trans_eMc[1], &trans_eMc[2]) != 4) {
+    case 2: {
+      std::stringstream ss(Ligne);
+      ss >> namoption >> trans_eMc[0] >> trans_eMc[1] >> trans_eMc[2];
+      if (ss.fail()) {
         fclose (fdtask);
         throw(vpException(vpException::badValue,
-                          "Cannot parse configuration file %s to retrieve rotation"));
+                          "Cannot parse configuration file %s to retrieve translation", filename.c_str()));
       }
       get_trans_eMc = true;
       break;
-
+    }
     default:
       vpERROR_TRACE ("Bad configuration file %s  "
-                     "ligne #%d.", filename, numLn);
+                     "ligne #%d.", filename.c_str(), numLn);
     } /* SWITCH */
   } /* WHILE */
 
@@ -494,19 +480,15 @@ vpViper850::parseConfigFile (const char * filename)
 
   // Compute the eMc matrix from the translations and rotations
   if (get_rot_eMc && get_trans_eMc) {
-    for (unsigned int i=0; i < 3; i ++) {
-      erc[i] = rot_eMc[i];
-      etc[i] = trans_eMc[i];
-    }
-
-    vpRotationMatrix eRc(erc);
-    this->eMc.buildFrom(etc, eRc);
+    this->set_eMc(trans_eMc,rot_eMc);
+  }
+  else {
+    throw vpRobotException (vpRobotException::readingParametersError,
+                            "Could not read translation and rotation parameters from config file %s", filename.c_str());
   }
 
   return;
 }
-#endif
-
 
 /*!
   Get the current intrinsic camera parameters obtained by calibration.
@@ -516,14 +498,12 @@ vpViper850::parseConfigFile (const char * filename)
   parameters. If XML is detected by ViSP, VISP_HAVE_XML2 macro is
   defined in include/visp3/core/vpConfig.h file.
 
-  \warning Thid method needs also an access to the file located on
-  Inria's NAS server and containing the camera parameters in XML
-  format. This access is available if VISP_HAVE_ACCESS_TO_NAS macro is
-  defined in include/visp3/core/vpConfig.h file.
+  \warning Thid method needs also an access to the files containing the
+  camera parameters in XML format. This access is available if
+  VISP_HAVE_VIPER850_DATA macro is defined in include/visp3/core/vpConfig.h file.
 
-  - If VISP_HAVE_ACCESS_TO_NAS and VISP_HAVE_XML2 macros are defined,
-  this method gets the camera parameters from
-  /udd/fspindle/robot/Viper850/current/include/const_camera_Viper850.xml
+  - If VISP_HAVE_VIPER850_DATA and VISP_HAVE_XML2 macros are defined,
+  this method gets the camera parameters from const_camera_Viper850.xml
   config file.
 
   - If these two macros are not defined, this method set the camera parameters
@@ -564,7 +544,7 @@ int main()
   // Get the intrinsic camera parameters depending on the image size
   // Camera parameters are read from
   // /udd/fspindle/robot/Viper850/current/include/const_camera_Viper850.xml
-  // if VISP_HAVE_ACCESS_TO_NAS and VISP_HAVE_XML2 macros are defined
+  // if VISP_HAVE_VIPER850_DATA and VISP_HAVE_XML2 macros are defined
   // in vpConfig.h file
   try {
     robot.getCameraParameters (cam, I.getWidth(), I.getHeight());
@@ -585,7 +565,7 @@ vpViper850::getCameraParameters (vpCameraParameters &cam,
                                  const unsigned int &image_width,
                                  const unsigned int &image_height) const
 {
-#if defined(VISP_HAVE_XML2) && defined (VISP_HAVE_ACCESS_TO_NAS)
+#if defined(VISP_HAVE_XML2) && defined (VISP_HAVE_VIPER850_DATA)
   vpXmlParserCamera parser;
   switch (getToolType()) {
   case vpViper850::TOOL_MARLIN_F033C_CAMERA: {
@@ -648,6 +628,10 @@ vpViper850::getCameraParameters (vpCameraParameters &cam,
     }
     break;
   }
+  case vpViper850::TOOL_CUSTOM: {
+    throw vpRobotException (vpRobotException::badValue,
+                            "No intrinsic parameters available for a custom tool");
+  }
   default: {
     vpERROR_TRACE ("This error should not occur!");
     //       vpERROR_TRACE ("Si elle survient malgre tout, c'est sans doute "
@@ -660,8 +644,7 @@ vpViper850::getCameraParameters (vpCameraParameters &cam,
     //        "fonction init(camera).");
     throw vpRobotException (vpRobotException::readingParametersError,
                             "Impossible to read the camera parameters.");
-    break;
-  }
+   }
   }
 #else
   // Set default parameters
@@ -730,11 +713,14 @@ vpViper850::getCameraParameters (vpCameraParameters &cam,
     }
     break;
   }
+  case vpViper850::TOOL_CUSTOM: {
+    throw vpRobotException (vpRobotException::badValue,
+                            "No intrinsic parameters available for a custom tool");
+  }
   default:
     vpERROR_TRACE ("This error should not occur!");
     throw vpRobotException (vpRobotException::readingParametersError,
                             "Impossible to read the camera parameters.");
-    break;
   }
 #endif
   return;
@@ -748,14 +734,12 @@ vpViper850::getCameraParameters (vpCameraParameters &cam,
   parameters. If XML is detected by ViSP, VISP_HAVE_XML2 macro is
   defined in include/visp3/core/vpConfig.h file.
 
-  \warning Thid method needs also an access to the file located on
-  Inria's NAS server and containing the camera parameters in XML
-  format. This access is available if VISP_HAVE_ACCESS_TO_NAS macro is
-  defined in include/visp3/core/vpConfig.h file.
+  \warning Thid method needs also an access to the files containing the
+  camera parameters in XML format. This access is available if
+  VISP_HAVE_VIPER850_DATA macro is defined in include/visp3/core/vpConfig.h file.
 
-  - If VISP_HAVE_ACCESS_TO_NAS and VISP_HAVE_XML2 macros are defined,
-  this method gets the camera parameters from
-  /udd/fspindle/robot/Viper850/current/include/const_camera_Viper850.xml
+  - If VISP_HAVE_VIPER850_DATA and VISP_HAVE_XML2 macros are defined,
+  this method gets the camera parameters from const_camera_Viper850.xml
   config file.
 
   - If these two macros are not defined, this method set the camera parameters
@@ -812,19 +796,17 @@ vpViper850::getCameraParameters (vpCameraParameters &cam,
 /*!
   \brief Get the current intrinsic camera parameters obtained by calibration.
 
-    \warning This method needs XML library to parse the file defined in
+  \warning This method needs XML library to parse the file defined in
   vpViper850::CONST_CAMERA_FILENAME and containing the camera
   parameters. If XML is detected by ViSP, VISP_HAVE_XML2 macro is
   defined in include/visp3/core/vpConfig.h file.
 
-  \warning Thid method needs also an access to the file located on
-  Inria's NAS server and containing the camera parameters in XML
-  format. This access is available if VISP_HAVE_ACCESS_TO_NAS macro is
-  defined in include/visp3/core/vpConfig.h file.
+  \warning Thid method needs also an access to the files containing the camera
+  parameters in XML format. This access is available if VISP_HAVE_VIPER850_DATA
+  macro is defined in include/visp3/core/vpConfig.h file.
 
-  - If VISP_HAVE_ACCESS_TO_NAS and VISP_HAVE_XML2 macros are defined,
-  this method gets the camera parameters from
-  /udd/fspindle/robot/Viper850/current/include/const_camera_Viper850.xml
+  - If VISP_HAVE_VIPER850_DATA and VISP_HAVE_XML2 macros are defined,
+  this method gets the camera parameters from const_camera_Viper850.xml
   config file.
 
   - If these two macros are not defined, this method set the camera parameters
