@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,7 +38,7 @@
 
 
 #include <visp3/core/vpConfig.h>
-#if defined(VISP_HAVE_MODULE_GUI) && (defined(_WIN32) || defined(VISP_HAVE_PTHREAD))
+#if defined(VISP_HAVE_MODULE_GUI) && ((defined(_WIN32) && !defined(WINRT_8_0)) || defined(VISP_HAVE_PTHREAD))
 #include <visp3/robot/vpSimulatorAfma6.h>
 #include <visp3/core/vpTime.h>
 #include <visp3/core/vpImagePoint.h>
@@ -49,8 +49,13 @@
 #include <cmath>    // std::fabs
 #include <limits>   // numeric_limits
 #include <string>
-const double vpSimulatorAfma6::defaultPositioningVelocity = 25.0;
 
+#include "../wireframe-simulator/vpBound.h"
+#include "../wireframe-simulator/vpVwstack.h"
+#include "../wireframe-simulator/vpRfstack.h"
+#include "../wireframe-simulator/vpScene.h"
+
+const double vpSimulatorAfma6::defaultPositioningVelocity = 25.0;
 
 /*!
   Basic constructor
@@ -66,12 +71,19 @@ vpSimulatorAfma6::vpSimulatorAfma6()
   tcur = vpTime::measureTimeMs();
 
   #if defined(_WIN32)
+#  ifdef WINRT_8_1
+  mutex_fMi = CreateMutexEx(NULL, NULL, 0, NULL);
+  mutex_artVel = CreateMutexEx(NULL, NULL, 0, NULL);
+  mutex_artCoord = CreateMutexEx(NULL, NULL, 0, NULL);
+  mutex_velocity = CreateMutexEx(NULL, NULL, 0, NULL);
+  mutex_display = CreateMutexEx(NULL, NULL, 0, NULL);
+#  else
   mutex_fMi = CreateMutex(NULL,FALSE,NULL);
   mutex_artVel = CreateMutex(NULL,FALSE,NULL);
   mutex_artCoord = CreateMutex(NULL,FALSE,NULL);
   mutex_velocity = CreateMutex(NULL,FALSE,NULL);
   mutex_display = CreateMutex(NULL,FALSE,NULL);
-
+#endif
 
   DWORD   dwThreadIdArray;
   hThread = CreateThread( 
@@ -114,12 +126,19 @@ vpSimulatorAfma6::vpSimulatorAfma6(bool do_display)
   tcur = vpTime::measureTimeMs();
   
     #if defined(_WIN32)
-  mutex_fMi = CreateMutex(NULL,FALSE,NULL);
-  mutex_artVel = CreateMutex(NULL,FALSE,NULL);
-  mutex_artCoord = CreateMutex(NULL,FALSE,NULL);
-  mutex_velocity = CreateMutex(NULL,FALSE,NULL);
-  mutex_display = CreateMutex(NULL,FALSE,NULL);
-
+#ifdef WINRT_8_1
+  mutex_fMi = CreateMutexEx(NULL, NULL, 0, NULL);
+  mutex_artVel = CreateMutexEx(NULL, NULL, 0, NULL);
+  mutex_artCoord = CreateMutexEx(NULL, NULL, 0, NULL);
+  mutex_velocity = CreateMutexEx(NULL, NULL, 0, NULL);
+  mutex_display = CreateMutexEx(NULL, NULL, 0, NULL);
+#else
+  mutex_fMi = CreateMutex(NULL, FALSE, NULL);
+  mutex_artVel = CreateMutex(NULL, FALSE, NULL);
+  mutex_artCoord = CreateMutex(NULL, FALSE, NULL);
+  mutex_velocity = CreateMutex(NULL, FALSE, NULL);
+  mutex_display = CreateMutex(NULL, FALSE, NULL);
+#endif
 
   DWORD   dwThreadIdArray;
   hThread = CreateThread( 
@@ -153,7 +172,11 @@ vpSimulatorAfma6::~vpSimulatorAfma6()
   robotStop = true;
   
   #if defined(_WIN32)
-  WaitForSingleObject(hThread,INFINITE);
+#  if defined(WINRT_8_1)
+  WaitForSingleObjectEx(hThread, INFINITE, FALSE);
+#  else // pure win32
+  WaitForSingleObject(hThread, INFINITE);
+#  endif
   CloseHandle(hThread);
   CloseHandle(mutex_fMi);
   CloseHandle(mutex_artVel);
@@ -291,7 +314,7 @@ vpSimulatorAfma6::initDisplay()
 */
 void
 vpSimulatorAfma6::init (vpAfma6::vpAfma6ToolType tool,
-           vpCameraParameters::vpCameraParametersProjType proj_model)
+                        vpCameraParameters::vpCameraParametersProjType proj_model)
 {
   this->projModel = proj_model;
   unsigned int name_length = 30; // the size of this kind of string "/afma6_tool_vacuum.bnd"
@@ -374,6 +397,7 @@ vpSimulatorAfma6::init (vpAfma6::vpAfma6ToolType tool,
       }
       break;
     }
+  case vpAfma6::TOOL_CUSTOM:
   case vpAfma6::TOOL_GENERIC_CAMERA: {
       std::cout << "The generic camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
     }
@@ -398,8 +422,8 @@ vpSimulatorAfma6::init (vpAfma6::vpAfma6ToolType tool,
 
 void
 vpSimulatorAfma6::getCameraParameters (vpCameraParameters &cam,
-				 const unsigned int &image_width,
-				 const unsigned int &image_height)
+                                       const unsigned int &image_width,
+                                       const unsigned int &image_height)
 {
   if (toolCustom)
   {
@@ -432,6 +456,7 @@ vpSimulatorAfma6::getCameraParameters (vpCameraParameters &cam,
     }
     break;
   }
+  case vpAfma6::TOOL_CUSTOM:
   case vpAfma6::TOOL_GENERIC_CAMERA:
   case vpAfma6::TOOL_VACUUM: {
       std::cout << "The generic camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
@@ -514,7 +539,6 @@ vpSimulatorAfma6::updateArticularPosition()
       }
     
       vpColVector articularCoordinates = get_artCoord();
-      articularCoordinates = get_artCoord();
       vpColVector articularVelocities = get_artVel();
     
       if (jointLimit)
@@ -743,7 +767,11 @@ vpSimulatorAfma6::compute_fMi()
   vpAfma6::get_fMc(q,fMit[7]);
   
   #if defined(_WIN32)
-  WaitForSingleObject(mutex_fMi,INFINITE);
+#  if defined(WINRT_8_1)
+  WaitForSingleObjectEx(mutex_fMi, INFINITE, FALSE);
+#  else // pure win32
+  WaitForSingleObject(mutex_fMi, INFINITE);
+#  endif
   for (int i = 0; i < 8; i++)
     fMi[i] = fMit[i];
   ReleaseMutex(mutex_fMi);
@@ -878,8 +906,6 @@ vpSimulatorAfma6::setVelocity (const vpRobot::vpControlFrameType frame, const vp
   
   vpColVector vel_sat(6);
 
-  double scale_trans_sat = 1;
-  double scale_rot_sat   = 1;
   double scale_sat       = 1;
   double vel_trans_max = getMaxTranslationVelocity();
   double vel_rot_max   = getMaxRotationVelocity();
@@ -895,65 +921,68 @@ vpSimulatorAfma6::setVelocity (const vpRobot::vpControlFrameType frame, const vp
     {
       if (vel.getRows() != 6)
       {
-	vpERROR_TRACE ("The velocity vector must have a size of 6 !!!!");
-	throw;
+        vpERROR_TRACE ("The velocity vector must have a size of 6 !!!!");
+        throw;
       }
-      
+
       for (unsigned int i = 0 ; i < 3; ++ i)
       {
         vel_abs = fabs (vel[i]);
         if (vel_abs > vel_trans_max && !jointLimit)
         {
-	  vel_trans_max = vel_abs;
-	  vpERROR_TRACE ("Excess velocity %g m/s in TRANSLATION "
-		         "(axis nr. %d).", vel[i], i+1);
+          vel_trans_max = vel_abs;
+          vpERROR_TRACE ("Excess velocity %g m/s in TRANSLATION "
+                         "(axis nr. %d).", vel[i], i+1);
         }
-      
+
         vel_abs = fabs (vel[i+3]);
         if (vel_abs > vel_rot_max && !jointLimit) {
-	  vel_rot_max = vel_abs;
-	  vpERROR_TRACE ("Excess velocity %g rad/s in ROTATION "
-		       "(axis nr. %d).", vel[i+3], i+4);
+          vel_rot_max = vel_abs;
+          vpERROR_TRACE ("Excess velocity %g rad/s in ROTATION "
+                         "(axis nr. %d).", vel[i+3], i+4);
         }
       }
-    
-      if (vel_trans_max > getMaxTranslationVelocity())                     
+
+      double scale_trans_sat = 1;
+      double scale_rot_sat   = 1;
+      if (vel_trans_max > getMaxTranslationVelocity())
         scale_trans_sat = getMaxTranslationVelocity() / vel_trans_max;
-    
+
       if (vel_rot_max > getMaxRotationVelocity())
-        scale_rot_sat = getMaxRotationVelocity() / vel_rot_max; 
-    
+        scale_rot_sat = getMaxRotationVelocity() / vel_rot_max;
+
       if ( (scale_trans_sat < 1) || (scale_rot_sat < 1) )
       {
-        if (scale_trans_sat < scale_rot_sat)  
-	  scale_sat = scale_trans_sat;                    
-        else                        
-	  scale_sat = scale_rot_sat;
+        if (scale_trans_sat < scale_rot_sat)
+          scale_sat = scale_trans_sat;
+        else
+          scale_sat = scale_rot_sat;
       }
       break;
     }
-    
-    // saturation in joint space
+
+      // saturation in joint space
     case vpRobot::ARTICULAR_FRAME :
     {
       if (vel.getRows() != 6)
       {
-	vpERROR_TRACE ("The velocity vector must have a size of 6 !!!!");
-	throw;
+        vpERROR_TRACE ("The velocity vector must have a size of 6 !!!!");
+        throw;
       }
       for (unsigned int i = 0 ; i < 6; ++ i)
       {
         vel_abs = fabs (vel[i]);
         if (vel_abs > vel_rot_max && !jointLimit)
         {
-	  vel_rot_max = vel_abs;
-	  vpERROR_TRACE ("Excess velocity %g rad/s in ROTATION "
-		       "(axis nr. %d).", vel[i], i+1);
+          vel_rot_max = vel_abs;
+          vpERROR_TRACE ("Excess velocity %g rad/s in ROTATION "
+                         "(axis nr. %d).", vel[i], i+1);
         }
       }
+      double scale_rot_sat   = 1;
       if (vel_rot_max > getMaxRotationVelocity())
-        scale_rot_sat = getMaxRotationVelocity() / vel_rot_max; 
-      if ( scale_rot_sat < 1 ) 
+        scale_rot_sat = getMaxRotationVelocity() / vel_rot_max;
+      if ( scale_rot_sat < 1 )
         scale_sat = scale_rot_sat;
       break;
     }
@@ -977,10 +1006,7 @@ vpSimulatorAfma6::computeArticularVelocity()
 {
   vpRobot::vpControlFrameType frame = getRobotFrame();
   
-  double scale_rot_sat   = 1;
-  double scale_sat       = 1;
   double vel_rot_max   = getMaxRotationVelocity();
-  double vel_abs;
   
   vpColVector articularCoordinates = get_artCoord();
   vpColVector velocityframe = get_velocity();
@@ -1023,8 +1049,6 @@ vpSimulatorAfma6::computeArticularVelocity()
     }
   }
   
-  
-  
   switch(frame)
   {
     case vpRobot::CAMERA_FRAME :
@@ -1032,7 +1056,7 @@ vpSimulatorAfma6::computeArticularVelocity()
     {
       for (unsigned int i = 0 ; i < 6; ++ i)
       {
-        vel_abs = fabs (articularVelocity[i]);
+        double vel_abs = fabs (articularVelocity[i]);
         if (vel_abs > vel_rot_max && !jointLimit)
         {
           vel_rot_max = vel_abs;
@@ -1040,6 +1064,8 @@ vpSimulatorAfma6::computeArticularVelocity()
              "(axis nr. %d).", articularVelocity[i], i+1);
         }
       }
+      double scale_rot_sat = 1;
+      double scale_sat     = 1;
       if (vel_rot_max > getMaxRotationVelocity())
         scale_rot_sat = getMaxRotationVelocity() / vel_rot_max; 
       if ( scale_rot_sat < 1 ) 
@@ -1324,7 +1350,7 @@ int main()
   try {
     robot.setPosition(vpRobot::CAMERA_FRAME, position);
   }
-  catch (vpRobotException e) {
+  catch (vpRobotException &e) {
     if (e.getCode() == vpRobotException::positionOutOfRangeError) {
     std::cout << "The position is out of range" << std::endl;
   }
@@ -1470,7 +1496,6 @@ vpSimulatorAfma6::setPosition(const vpRobot::vpControlFrameType frame,const vpCo
       throw vpRobotException (vpRobotException::lowLevelError,
 			      "Positionning error: "
 			      "Mixt frame not implemented.");
-      break ;
     }
   }
 }
@@ -1719,7 +1744,6 @@ vpSimulatorAfma6::getPosition(const vpRobot::vpControlFrameType frame, vpColVect
       throw vpRobotException (vpRobotException::lowLevelError,
 			      "Positionning error: "
 			      "Mixt frame not implemented.");
-      break ;
     }
   }
 }
@@ -1975,7 +1999,6 @@ vpSimulatorAfma6::getDisplacement(vpRobot::vpControlFrameType frame,
       {
         std::cout << "getDisplacement() CAMERA_FRAME not implemented\n";
         return;
-        break ;
       }
 
       case vpRobot::ARTICULAR_FRAME: 
@@ -1988,15 +2011,13 @@ vpSimulatorAfma6::getDisplacement(vpRobot::vpControlFrameType frame,
       {
         std::cout << "getDisplacement() REFERENCE_FRAME not implemented\n";
         return;
-        break ;
-      }
+       }
 
       case vpRobot::MIXT_FRAME: 
       {
         std::cout << "getDisplacement() MIXT_FRAME not implemented\n";
         return;
-        break ;
-      }
+       }
     }
   }
   else 
@@ -2055,58 +2076,64 @@ robot.setPosition(vpRobot::ARTICULAR_FRAME, q); // Move to the joint position
 \sa savePosFile()
 */
 bool
-vpSimulatorAfma6::readPosFile(const char *filename, vpColVector &q)
+vpSimulatorAfma6::readPosFile(const std::string &filename, vpColVector &q)
 {
-  FILE * fd ;
-  fd = fopen(filename, "r") ;
-  if (fd == NULL)
+  std::ifstream fd(filename.c_str(), std::ios::in);
+
+  if(! fd.is_open()) {
     return false;
+  }
 
-  char line[FILENAME_MAX];
-  char dummy[FILENAME_MAX];
-  char head[] = "R:";
-  bool sortie = false;
+  std::string line;
+  std::string key("R:");
+  std::string id("#AFMA6 - Position");
+  bool pos_found = false;
+  int lineNum = 0;
 
-  do {
-    // Saut des lignes commencant par #
-    if (fgets (line, FILENAME_MAX, fd) != NULL) {
-      if ( strncmp (line, "#", 1) != 0) {
-        // La ligne n'est pas un commentaire
-        if ( strncmp (line, head, sizeof(head)-1) == 0) {
-          sortie = true; 	// Position robot trouvee.
-        }
-        // 	else
-        // 	  return (false); // fin fichier sans position robot.
+  q.resize(njoint);
+
+  while(std::getline(fd, line)) {
+    lineNum ++;
+    if (lineNum == 1) {
+      if(! (line.compare(0, id.size(), id) == 0)) { // check if Afma6 position file
+        std::cout << "Error: this position file " << filename << " is not for Afma6 robot" << std::endl;
+        return false;
       }
     }
-    else {
-      fclose(fd) ;
-      return (false);		/* fin fichier 	*/
+    if((line.compare(0, 1, "#") == 0)) { // skip comment
+      continue;
     }
+    if((line.compare(0, key.size(), key) == 0)) { // decode position
+      // check if there are at least njoint values in the line
+      std::vector<std::string> chain = vpIoTools::splitChain(line, std::string(" "));
+      if (chain.size() < njoint+1) // try to split with tab separator
+        chain = vpIoTools::splitChain(line, std::string("\t"));
+      if(chain.size() < njoint+1)
+        continue;
 
-  }
-  while ( sortie != true );
-
-  // Lecture des positions
-  q.resize(njoint);
-  int ret = sscanf(line, "%s %lf %lf %lf %lf %lf %lf",
-                   dummy,
-                   &q[0], &q[1], &q[2], &q[3], &q[4], &q[5]);
-
-  if (ret != 7) {
-    fclose(fd) ;
-    return false;
+      std::istringstream ss(line);
+      std::string key_;
+      ss >> key_;
+      for (unsigned int i=0; i< njoint; i++)
+        ss >> q[i];
+      pos_found = true;
+      break;
+    }
   }
 
   // converts rotations from degrees into radians
-  //q.deg2rad();
-  
   q[3] = vpMath::rad(q[3]);
   q[4] = vpMath::rad(q[4]);
   q[5] = vpMath::rad(q[5]);
 
-  fclose(fd) ;
-  return (true);
+  fd.close();
+
+  if (!pos_found) {
+    std::cout << "Error: unable to find a position for Afma6 robot in " << filename << std::endl;
+    return false;
+  }
+
+  return true;
 }
 
 /*!
@@ -2132,11 +2159,10 @@ vpSimulatorAfma6::readPosFile(const char *filename, vpColVector &q)
   \sa readPosFile()
 */
 bool
-vpSimulatorAfma6::savePosFile(const char *filename, const vpColVector &q)
+vpSimulatorAfma6::savePosFile(const std::string &filename, const vpColVector &q)
 {
-
   FILE * fd ;
-  fd = fopen(filename, "w") ;
+  fd = fopen(filename.c_str(), "w") ;
   if (fd == NULL)
     return false;
 
@@ -2374,6 +2400,10 @@ vpSimulatorAfma6::initArms()
       strcat(name_arm,"/afma6_tool_vacuum.bnd");
       break;
     }
+  case vpAfma6::TOOL_CUSTOM: {
+    std::cout << "The custom tool is not handled in vpSimulatorAfma6.cpp" << std::endl;
+    break;
+  }
   case vpAfma6::TOOL_GENERIC_CAMERA: {
       std::cout << "The generic camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
       break;
@@ -2570,14 +2600,13 @@ vpSimulatorAfma6::setPosition(const vpHomogeneousMatrix &cdMo_, vpImage<unsigned
 	vpTranslationVector cdTc;vpRotationMatrix cdRc;vpThetaUVector cdTUc;
 	vpColVector err(6);err=1.;
 	const double lambda = 5.;
-	double t;
 
 	vpVelocityTwistMatrix cVe;
 
 	unsigned int i,iter=0;
 	while((iter++<300) & (err.euclideanNorm()>errMax))
 		{
-		t = vpTime::measureTimeMs();
+    double t = vpTime::measureTimeMs();
 
 		// update image
 		if(Iint != NULL)
