@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -62,6 +62,7 @@
 #include <visp3/core/vpFrameGrabberException.h>
 //#include <visp3/io/vpImageIo.h>
 #include <visp3/core/vpImageConvert.h>
+#include <visp3/core/vpImageTools.h>
 
 const unsigned int vpV4l2Grabber::DEFAULT_INPUT = 2;
 const unsigned int vpV4l2Grabber::DEFAULT_SCALE = 2;
@@ -94,7 +95,7 @@ const unsigned int vpV4l2Grabber::FRAME_SIZE    = 288;
     to change it.
 
   - Image size acquisition: vpV4l2Grabber::DEFAULT_SCALE. Use either setScale()
-    or setWidth() and setHeight to change it.
+    or setWidth() and setHeight() to change it.
 
     \code
     vpImage<unsigned char> I; // Grey level image
@@ -107,13 +108,47 @@ const unsigned int vpV4l2Grabber::FRAME_SIZE    = 288;
     g.open(I);        // Open the grabber
 
     g.acquire(I);     // Acquire a 768x576 grey image
-
     \endcode
 
+  The grabber allows also to grab a portion of an image using a region of interest.
+  The following example shows how to grab a 320x240 region located on the top/left
+  corner of the image that has a higher resolution (ie 640x480).
+
+  \code
+#include <visp3/sensor/vpV4l2Grabber.h>
+#include <visp3/io/vpImageIo.h>
+#include <visp3/gui/vpDisplayX.h>
+
+int main()
+{
+#if defined(VISP_HAVE_V4L2) && defined(VISP_HAVE_X11)
+  vpDisplayX *d;
+  vpImage<vpRGBa> I;
+  vpRect roi(0, 0, 320, 240); // specify the region to crop
+
+  vpV4l2Grabber g;
+
+  bool first = true;
+  while (1) {
+    g.acquire(I, roi);
+    if(first) {
+      d = new vpDisplayX(I);
+      first = false;
+    }
+    vpDisplay::display(I);
+    vpDisplay::flush(I);
+    if (vpDisplay::getClick(I, false))
+      break;
+  }
+  vpImageIo::write(I, "image.pgm"); // Save the last image
+  delete d;
+#endif
+  \endcode
+
 */
 vpV4l2Grabber::vpV4l2Grabber()
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL),
-    fps(0), fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
+    fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
     waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0), streaming(false),
     m_input(vpV4l2Grabber::DEFAULT_INPUT),
     m_framerate(vpV4l2Grabber::framerate_25fps),
@@ -172,7 +207,7 @@ vpV4l2Grabber::vpV4l2Grabber()
 */
 vpV4l2Grabber::vpV4l2Grabber(bool verbose)
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL),
-    fps(0), fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
+    fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
     waiton_cpt(0), index_buffer(0), m_verbose(verbose), m_nbuffers(3), field(0), streaming(false),
     m_input(vpV4l2Grabber::DEFAULT_INPUT),
     m_framerate(vpV4l2Grabber::framerate_25fps),
@@ -222,7 +257,7 @@ vpV4l2Grabber::vpV4l2Grabber(bool verbose)
 */
 vpV4l2Grabber::vpV4l2Grabber(unsigned input, unsigned scale)
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL),
-    fps(0), fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
+    fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
     waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0), streaming(false),
     m_input(vpV4l2Grabber::DEFAULT_INPUT),
     m_framerate(vpV4l2Grabber::framerate_25fps),
@@ -271,7 +306,7 @@ vpV4l2Grabber::vpV4l2Grabber(unsigned input, unsigned scale)
 */
 vpV4l2Grabber::vpV4l2Grabber(vpImage<unsigned char> &I, unsigned input, unsigned scale )
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL),
-    fps(0), fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
+    fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
     waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0), streaming(false),
     m_input(vpV4l2Grabber::DEFAULT_INPUT),
     m_framerate(vpV4l2Grabber::framerate_25fps),
@@ -323,7 +358,7 @@ vpV4l2Grabber::vpV4l2Grabber(vpImage<unsigned char> &I, unsigned input, unsigned
 */
 vpV4l2Grabber::vpV4l2Grabber(vpImage<vpRGBa> &I, unsigned input, unsigned scale )
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL),
-    fps(0), fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
+    fmt_v4l2(), fmt_me(), reqbufs(), buf_v4l2(NULL), buf_me(NULL), queue(0),
     waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0), streaming(false),
     m_input(vpV4l2Grabber::DEFAULT_INPUT),
     m_framerate(vpV4l2Grabber::framerate_25fps),
@@ -381,7 +416,7 @@ vpV4l2Grabber::setScale(unsigned scale)
 
     vpERROR_TRACE("Wrong scale %d, scale should be between 1 and 16",scale) ;
     throw (vpFrameGrabberException(vpFrameGrabberException::settingError,
-				   "Wrong scale") );
+                                   "Wrong scale") );
   }
 
   setWidth(640/scale);
@@ -417,37 +452,37 @@ vpV4l2Grabber::open(vpImage<unsigned char> &I)
   }
   catch(...) {
     if (m_verbose) {
-      std::cout << "Requested pixel format [" << req_pixelformat 
-		<< "] not compatible with camera" << std::endl;
+      std::cout << "Requested pixel format [" << req_pixelformat
+                << "] not compatible with camera" << std::endl;
       std::cout << "Try to found a compatible pixel format..." << std::endl;
     }
     
     // try to fing a compatible format
     for (int format=0; format< (int)V4L2_MAX_FORMAT; format ++) {
       if (format == req_pixelformat) {
-	continue;
+        continue;
       }
       try {
-	setPixelFormat((vpV4l2PixelFormatType)format);
-	setFormat();
-	startStreaming();
-  if (m_verbose)
-    std::cout << "This format [" << m_pixelformat
-		    << "] is compatible with camera" << std::endl;
-	
-	break;
+        setPixelFormat((vpV4l2PixelFormatType)format);
+        setFormat();
+        startStreaming();
+        if (m_verbose)
+          std::cout << "This format [" << m_pixelformat
+                    << "] is compatible with camera" << std::endl;
+
+        break;
       }
       catch (...) {
-  if (m_verbose)
-    std::cout << "This format [" << m_pixelformat
-		    << "] is not compatible with camera" << std::endl;
-	if (format == (int)V4L2_MAX_FORMAT) {
-	  std::cout << "No pixel format compatible with the camera was found" << std::endl;
-	  close();
+        if (m_verbose)
+          std::cout << "This format [" << m_pixelformat
+                    << "] is not compatible with camera" << std::endl;
+        if (format == (int)V4L2_MAX_FORMAT) {
+          std::cout << "No pixel format compatible with the camera was found" << std::endl;
+          close();
 
-	  throw (vpFrameGrabberException(vpFrameGrabberException::settingError,
-				   "No pixel format compatible with the camera was found"));
-	}
+          throw (vpFrameGrabberException(vpFrameGrabberException::settingError,
+                                         "No pixel format compatible with the camera was found"));
+        }
       }
     }
   }
@@ -486,29 +521,29 @@ vpV4l2Grabber::open(vpImage<vpRGBa> &I)
   catch(...) {
     if (m_verbose) {
       std::cout << "Requested pixel format [" << m_pixelformat
-		<< "] not compatible with camera" << std::endl;
+                << "] not compatible with camera" << std::endl;
       std::cout << "Try to found a compatible pixel format..." << std::endl;
     }
     
     // try to fing a compatible format
     for (int format=0; format< (int)V4L2_MAX_FORMAT; format ++) {
       if (format == req_pixelformat) {
-	continue;
+        continue;
       }
       try {
-	setPixelFormat((vpV4l2PixelFormatType)format);
-	setFormat();
-	startStreaming();
-  if (m_verbose)
-    std::cout << "This format [" << m_pixelformat
-		    << "] is compatible with camera" << std::endl;
-	
-	break;
+        setPixelFormat((vpV4l2PixelFormatType)format);
+        setFormat();
+        startStreaming();
+        if (m_verbose)
+          std::cout << "This format [" << m_pixelformat
+                    << "] is compatible with camera" << std::endl;
+
+        break;
       }
       catch (...) {
-  if (m_verbose)
-    std::cout << "This format [" << m_pixelformat
-		    << "] is not compatible with camera" << std::endl;
+        if (m_verbose)
+          std::cout << "This format [" << m_pixelformat
+                    << "] is not compatible with camera" << std::endl;
 
       }
     }
@@ -519,8 +554,6 @@ vpV4l2Grabber::open(vpImage<vpRGBa> &I)
   init = true;
 }
 
-
-
 /*!
   Acquire a grey level image.
 
@@ -535,8 +568,28 @@ void
 vpV4l2Grabber::acquire(vpImage<unsigned char> &I)
 {
   struct timeval timestamp;
+  vpRect roi;
 
-  acquire(I, timestamp);
+  acquire(I, timestamp, roi);
+}
+
+/*!
+  Acquire a grey level image.
+
+  \param I : Image data structure (8 bits image)
+  \param roi : Region of interest to grab from the full resolution image.
+
+  \exception vpFrameGrabberException::initializationError : Frame grabber not
+  initialized.
+
+  \sa getField()
+*/
+void
+vpV4l2Grabber::acquire(vpImage<unsigned char> &I, const vpRect &roi)
+{
+  struct timeval timestamp;
+
+  acquire(I, timestamp, roi);
 }
 
 /*!
@@ -545,7 +598,11 @@ vpV4l2Grabber::acquire(vpImage<unsigned char> &I)
   \param I : Image data structure (8 bits image).
 
   \param timestamp : Timeval data structure providing the unix time
-  at which the frame was captured in the ringbuffer.
+  at which the frame was captured in the ringbuffer. \b Warning: some v4l2 drivers do not return
+  the time since 1970 (the one returned by gettimeofday() or vpTime) but rather a time that counts
+  from the boot time (i.e. uptime).
+
+  \param roi : Region of interest to grab from the full resolution image. By default acquire the whole image.
 
   \exception vpFrameGrabberException::initializationError : Frame grabber not
   initialized.
@@ -553,7 +610,7 @@ vpV4l2Grabber::acquire(vpImage<unsigned char> &I)
   \sa getField()
 */
 void
-vpV4l2Grabber::acquire(vpImage<unsigned char> &I, struct timeval &timestamp)
+vpV4l2Grabber::acquire(vpImage<unsigned char> &I, struct timeval &timestamp, const vpRect &roi)
 {
   if (init==false)
   {
@@ -565,34 +622,59 @@ vpV4l2Grabber::acquire(vpImage<unsigned char> &I, struct timeval &timestamp)
     close();
 
     throw (vpFrameGrabberException(vpFrameGrabberException::initializationError,
-				   "V4l2 frame grabber not initialized") );
+                                   "V4l2 frame grabber not initialized") );
   }
 
-  unsigned  char *bitmap ;
+  unsigned char *bitmap ;
   bitmap = waiton(index_buffer, timestamp);
 
-  if ((I.getWidth() != width)||(I.getHeight() != height))
-    I.resize(height, width) ;
-
+  if (roi == vpRect())
+    I.resize(height, width);
+  else
+    I.resize((unsigned int)roi.getHeight(), (unsigned int)roi.getWidth());
   switch(m_pixelformat) {
   case V4L2_GREY_FORMAT:
-    memcpy(I.bitmap, bitmap, height * width*sizeof(unsigned char));
+    if (roi == vpRect())
+      memcpy(I.bitmap, bitmap, height * width*sizeof(unsigned char));
+    else
+      vpImageTools::crop(bitmap, width, height, roi, I);
     break;
-  case V4L2_RGB24_FORMAT:
-    vpImageConvert::RGBToGrey((unsigned char *) bitmap, I.bitmap, width*height);
-
+  case V4L2_RGB24_FORMAT: // tested
+    if (roi == vpRect())
+      vpImageConvert::RGBToGrey((unsigned char *) bitmap, I.bitmap, width*height);
+    else {
+      vpImage<unsigned char> tmp(height, width);
+      vpImageConvert::RGBToGrey((unsigned char *) bitmap, tmp.bitmap, width*height);
+      vpImageTools::crop(tmp, roi, I);
+    }
     break;
   case V4L2_RGB32_FORMAT:
-    vpImageConvert::RGBaToGrey((unsigned char *) bitmap, I.bitmap, width*height);
+    if (roi == vpRect())
+      vpImageConvert::RGBaToGrey((unsigned char *) bitmap, I.bitmap, width*height);
+    else {
+      vpImage<unsigned char> tmp(height, width);
+      vpImageConvert::RGBaToGrey((unsigned char *) bitmap, tmp.bitmap, width*height);
+      vpImageTools::crop(tmp, roi, I);
+    }
 
     break;
-  case V4L2_BGR24_FORMAT:
-    vpImageConvert::BGRToGrey( (unsigned char *) bitmap, I.bitmap, width, height, false);
-
+  case V4L2_BGR24_FORMAT: // tested
+    if (roi == vpRect())
+      vpImageConvert::BGRToGrey( (unsigned char *) bitmap, I.bitmap, width, height, false);
+    else {
+      vpImage<unsigned char> tmp(height, width);
+      vpImageConvert::BGRToGrey( (unsigned char *) bitmap, tmp.bitmap, width, height, false);
+      vpImageTools::crop(tmp, roi, I);
+    }
     break;
-  case V4L2_YUYV_FORMAT:
-    vpImageConvert::YUYVToGrey( (unsigned char *) bitmap, I.bitmap, width*height);
-
+  case V4L2_YUYV_FORMAT: // tested
+    if (roi == vpRect())
+      vpImageConvert::YUYVToGrey( (unsigned char *) bitmap, I.bitmap, width*height);
+    else {
+      vpImage<unsigned char> tmp(height, width);
+      vpImageConvert::YUYVToGrey( (unsigned char *) bitmap, tmp.bitmap, width*height);
+      vpImageTools::crop(tmp, roi, I);
+    }
     break;
   default:
     std::cout << "V4L2 conversion not handled" << std::endl;
@@ -616,8 +698,28 @@ void
 vpV4l2Grabber::acquire(vpImage<vpRGBa> &I)
 {
   struct timeval timestamp;
+  vpRect roi;
 
-  acquire(I, timestamp);
+  acquire(I, timestamp, roi);
+}
+
+/*!
+  Acquire a color image.
+
+  \param I : Image data structure (32 bits image)
+  \param roi : Region of interest to grab from the full resolution image.
+
+  \exception vpFrameGrabberException::initializationError : Frame grabber not
+  initialized.
+
+  \sa getField()
+*/
+void
+vpV4l2Grabber::acquire(vpImage<vpRGBa> &I, const vpRect &roi)
+{
+  struct timeval timestamp;
+
+  acquire(I, timestamp, roi);
 }
 
 /*!
@@ -626,7 +728,11 @@ vpV4l2Grabber::acquire(vpImage<vpRGBa> &I)
   \param I : Image data structure (32 bits image).
 
   \param timestamp : Timeval data structure providing the unix time
-  at which the frame was captured in the ringbuffer.
+  at which the frame was captured in the ringbuffer. \b Warning: some v4l2 drivers do not return
+  the time since 1970 (the one returned by gettimeofday() or vpTime) but rather a time that counts
+  from the boot time (i.e. uptime).
+
+  \param roi : Region of interest to grab from the full resolution image. By default acquire the whole image.
 
   \exception vpFrameGrabberException::initializationError : Frame grabber not
   initialized.
@@ -634,7 +740,7 @@ vpV4l2Grabber::acquire(vpImage<vpRGBa> &I)
   \sa getField()
 */
 void
-vpV4l2Grabber::acquire(vpImage<vpRGBa> &I, struct timeval &timestamp)
+vpV4l2Grabber::acquire(vpImage<vpRGBa> &I, struct timeval &timestamp, const vpRect &roi)
 {
   if (init==false)
   {
@@ -646,36 +752,66 @@ vpV4l2Grabber::acquire(vpImage<vpRGBa> &I, struct timeval &timestamp)
     close();
 
     throw (vpFrameGrabberException(vpFrameGrabberException::initializationError,
-				   "V4l2 frame grabber not initialized") );
+                                   "V4l2 frame grabber not initialized") );
   }
 
   unsigned  char *bitmap ;
   bitmap = waiton(index_buffer, timestamp);
 
-  if ((I.getWidth() != width)||(I.getHeight() != height))
-    I.resize(height, width) ;
+  if (roi == vpRect())
+    I.resize(height, width);
+  else
+    I.resize((unsigned int)roi.getHeight(), (unsigned int)roi.getWidth());
 
   // The framegrabber acquire aRGB format. We just shift the data from 1 byte all the data and initialize the last byte
 
   switch(m_pixelformat) {
   case V4L2_GREY_FORMAT:
-    vpImageConvert::GreyToRGBa((unsigned char *) bitmap, (unsigned char *) I.bitmap, width*height);
+    if (roi == vpRect())
+      vpImageConvert::GreyToRGBa((unsigned char *) bitmap, (unsigned char *) I.bitmap, width*height);
+    else
+      vpImageTools::crop(bitmap, width, height, roi, I);
     break;
-  case V4L2_RGB24_FORMAT:
-    vpImageConvert::RGBToRGBa((unsigned char *) bitmap, (unsigned char *) I.bitmap, width*height);
-
+  case V4L2_RGB24_FORMAT: // tested
+    if (roi == vpRect())
+      vpImageConvert::RGBToRGBa((unsigned char *) bitmap, (unsigned char *) I.bitmap, width*height);
+    else {
+      vpImage<vpRGBa> tmp(height, width);
+      vpImageConvert::RGBToRGBa((unsigned char *) bitmap, (unsigned char *) tmp.bitmap, width*height);
+      vpImageTools::crop(tmp, roi, I);
+    }
     break;
   case V4L2_RGB32_FORMAT:
-    // The framegrabber acquire aRGB format. We just shift the data
-    // from 1 byte all the data and initialize the last byte
-    memcpy(I.bitmap, bitmap + 1, height * width * sizeof(vpRGBa) - 1);
-    I[height-1][width-1].A = 0;
+    if (roi == vpRect()) {
+      // The framegrabber acquire aRGB format. We just shift the data
+      // from 1 byte all the data and initialize the last byte
+      memcpy(I.bitmap, bitmap + 1, height * width * sizeof(vpRGBa) - 1);
+      I[height-1][width-1].A = 0;
+    }
+    else {
+      for(unsigned int i=0; i<I.getHeight(); i++) {
+        memcpy(I.bitmap, bitmap + 1 + (unsigned int)(roi.getTop()*width + roi.getLeft()), I.getWidth() * sizeof(vpRGBa) - 1);
+        I[i][I.getWidth()-1].A = 0;
+      }
+    }
     break;
-  case V4L2_BGR24_FORMAT:
-    vpImageConvert::BGRToRGBa((unsigned char *) bitmap, (unsigned char *) I.bitmap, width, height, false);
+  case V4L2_BGR24_FORMAT: // tested
+    if (roi == vpRect())
+      vpImageConvert::BGRToRGBa((unsigned char *) bitmap, (unsigned char *) I.bitmap, width, height, false);
+    else {
+      vpImage<vpRGBa> tmp(height, width);
+      vpImageConvert::BGRToRGBa((unsigned char *) bitmap, (unsigned char *) tmp.bitmap, width, height, false);
+      vpImageTools::crop(tmp, roi, I);
+    }
     break;
-  case V4L2_YUYV_FORMAT:
-    vpImageConvert::YUYVToRGBa( (unsigned char *) bitmap, (unsigned char *) I.bitmap, width, height); 
+  case V4L2_YUYV_FORMAT: // tested
+    if (roi == vpRect())
+      vpImageConvert::YUYVToRGBa( (unsigned char *) bitmap, (unsigned char *) I.bitmap, width, height);
+    else {
+      vpImage<vpRGBa> tmp(height, width);
+      vpImageConvert::YUYVToRGBa((unsigned char *) bitmap, (unsigned char *) tmp.bitmap, width, height);
+      vpImageTools::crop(tmp, roi, I);
+    }
     break;
   default:
     std::cout << "V4l2 conversion not handled" << std::endl;
@@ -709,7 +845,7 @@ vpV4l2Grabber::getField()
     close();
 
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "V4l2 returns a bad frame field") );
+                                   "V4l2 returns a bad frame field") );
     return false;
   }
 }
@@ -730,12 +866,12 @@ vpV4l2Grabber::getField()
 void
 vpV4l2Grabber::setFramerate(vpV4l2Grabber::vpV4l2FramerateType framerate)
 {
-   this->m_framerate = framerate;
+  this->m_framerate = framerate;
 
-   if (framerate == vpV4l2Grabber::framerate_25fps)
-     setFrameFormat(V4L2_IMAGE_FORMAT);
-   else
-     setFrameFormat(V4L2_FRAME_FORMAT);
+  if (framerate == vpV4l2Grabber::framerate_25fps)
+    setFrameFormat(V4L2_IMAGE_FORMAT);
+  else
+    setFrameFormat(V4L2_FRAME_FORMAT);
 }
 
 /*!
@@ -793,20 +929,20 @@ void
 vpV4l2Grabber::open()
 {
   /* Open Video Device */
-  struct stat st; 
+  struct stat st;
   
   if (-1 == stat (device, &st)) {
     fprintf (stderr, "Cannot identify '%s': %d, %s\n",
-	     device, errno, strerror (errno));
+             device, errno, strerror (errno));
     throw (vpFrameGrabberException(vpFrameGrabberException::initializationError,
-				   "Cannot identify video device") );
+                                   "Cannot identify video device") );
 
   }
   
   if (!S_ISCHR (st.st_mode)) {
     fprintf (stderr, "%s is no device\n", device);
     throw (vpFrameGrabberException(vpFrameGrabberException::initializationError,
-				   "No device") );
+                                   "No device") );
     
   }
   fd = v4l2_open (device, O_RDWR | O_NONBLOCK, 0);
@@ -815,7 +951,7 @@ vpV4l2Grabber::open()
 
     vpERROR_TRACE ("No video device \"%s\"\n", device);
     throw (vpFrameGrabberException(vpFrameGrabberException::initializationError,
-				   "Can't access to video device") );
+                                   "Can't access to video device") );
 
   }
 
@@ -838,18 +974,18 @@ vpV4l2Grabber::open()
     close();
     fprintf (stderr, "%s is no V4L2 device\n", device);
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Is not a V4L2 device") );
+                                   "Is not a V4L2 device") );
   }
   if (m_verbose) {
     fprintf(stdout, "v4l2 info:\n"
-	    "     device: %s\n"
-	    "     %s %d.%d.%d / %s @ %s\n",
-	    device,
-	    cap.driver,
-	    (cap.version >> 16) & 0xff,
-	    (cap.version >>  8) & 0xff,
-	    cap.version         & 0xff,
-	    cap.card, cap.bus_info);
+                    "     device: %s\n"
+                    "     %s %d.%d.%d / %s @ %s\n",
+            device,
+            cap.driver,
+            (cap.version >> 16) & 0xff,
+            (cap.version >>  8) & 0xff,
+            cap.version         & 0xff,
+            cap.card, cap.bus_info);
     if (cap.capabilities & V4L2_CAP_VIDEO_OVERLAY)
       fprintf(stdout, "     Support overlay\n");
     else
@@ -918,7 +1054,7 @@ vpV4l2Grabber::getCapabilities()
     close();
 
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't get video parameters") );
+                                   "Can't get video parameters") );
   }
 }
 
@@ -944,19 +1080,19 @@ vpV4l2Grabber::setFormat()
   // because initialized later by an ioctl call to VIDIOC_S_FMT
 
   switch(m_pixelformat) {
-  case V4L2_GREY_FORMAT : fmt_me.pixelformat = V4L2_PIX_FMT_GREY; 
+  case V4L2_GREY_FORMAT : fmt_me.pixelformat = V4L2_PIX_FMT_GREY;
     if (m_verbose)
       fprintf(stdout,"v4l2: new capture params (V4L2_PIX_FMT_GREY)\n");
     break;
-  case V4L2_RGB24_FORMAT: fmt_me.pixelformat = V4L2_PIX_FMT_RGB24; 
+  case V4L2_RGB24_FORMAT: fmt_me.pixelformat = V4L2_PIX_FMT_RGB24;
     if (m_verbose)
       fprintf(stdout,"v4l2: new capture params (V4L2_PIX_FMT_RGB24)\n");
     break;
-  case V4L2_RGB32_FORMAT: fmt_me.pixelformat = V4L2_PIX_FMT_RGB32; 
+  case V4L2_RGB32_FORMAT: fmt_me.pixelformat = V4L2_PIX_FMT_RGB32;
     if (m_verbose)
       fprintf(stdout,"v4l2: new capture params (V4L2_PIX_FMT_RGB32)\n");
     break;
-  case V4L2_BGR24_FORMAT: fmt_me.pixelformat = V4L2_PIX_FMT_BGR24; 
+  case V4L2_BGR24_FORMAT: fmt_me.pixelformat = V4L2_PIX_FMT_BGR24;
     if (m_verbose)
       fprintf(stdout,"v4l2: new capture params (V4L2_PIX_FMT_BGR24)\n");
     break;
@@ -969,7 +1105,7 @@ vpV4l2Grabber::setFormat()
     close();
 
     throw (vpFrameGrabberException(vpFrameGrabberException::settingError,
-				   "Bad format, probably do to a wrong scale"));
+                                   "Bad format, probably do to a wrong scale"));
   }
 
   /* Get Video Format */
@@ -981,7 +1117,7 @@ vpV4l2Grabber::setFormat()
     close();
 
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't get video format") );
+                                   "Can't get video format") );
   }
   fmt_v4l2.fmt.pix.pixelformat  = fmt_me.pixelformat;
   fmt_v4l2.fmt.pix.width        = fmt_me.width;
@@ -1004,7 +1140,7 @@ vpV4l2Grabber::setFormat()
     close();
 
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Unrecognized frame format") );
+                                   "Unrecognized frame format") );
   }
 
   //height and width of the captured image or frame
@@ -1016,12 +1152,12 @@ vpV4l2Grabber::setFormat()
 
   if (v4l2_ioctl(fd, VIDIOC_S_FMT, &fmt_v4l2) == -1) {
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't set video format") );
+                                   "Can't set video format") );
   }
 
   if (fmt_v4l2.fmt.pix.pixelformat != fmt_me.pixelformat) {
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-  				   "Bad pixel format") );
+                                   "Bad pixel format") );
   }
 
   /* Buggy driver paranoia. */
@@ -1038,13 +1174,13 @@ vpV4l2Grabber::setFormat()
 
   if (m_verbose) {
     fprintf(stdout,"v4l2: new capture params (%dx%d, %c%c%c%c, %d byte, %d bytes per line)\n",
-	    fmt_me.width, fmt_me.height,
-	    fmt_v4l2.fmt.pix.pixelformat & 0xff,
-	    (fmt_v4l2.fmt.pix.pixelformat >>  8) & 0xff,
-	    (fmt_v4l2.fmt.pix.pixelformat >> 16) & 0xff,
-	    (fmt_v4l2.fmt.pix.pixelformat >> 24) & 0xff,
-	    fmt_v4l2.fmt.pix.sizeimage,
-	    fmt_v4l2.fmt.pix.bytesperline);
+            fmt_me.width, fmt_me.height,
+            fmt_v4l2.fmt.pix.pixelformat & 0xff,
+            (fmt_v4l2.fmt.pix.pixelformat >>  8) & 0xff,
+            (fmt_v4l2.fmt.pix.pixelformat >> 16) & 0xff,
+            (fmt_v4l2.fmt.pix.pixelformat >> 24) & 0xff,
+            fmt_v4l2.fmt.pix.sizeimage,
+            fmt_v4l2.fmt.pix.bytesperline);
   }
 
 }
@@ -1075,12 +1211,12 @@ vpV4l2Grabber::startStreaming()
   {
     if (EINVAL == errno) {
       fprintf (stderr, "%s does not support "
-                                 "memory mapping\n", device);
+                       "memory mapping\n", device);
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "Does not support memory mapping") );
+                                     "Does not support memory mapping") );
     }
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't require video buffers") );
+                                   "Can't require video buffers") );
   }
 
   for (unsigned i = 0; i < reqbufs.count; i++) {
@@ -1093,7 +1229,7 @@ vpV4l2Grabber::startStreaming()
     if (v4l2_ioctl(fd, VIDIOC_QUERYBUF, &buf_v4l2[i]) == -1)
     {
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't query video buffers") );
+                                     "Can't query video buffers") );
     }
     memcpy(&buf_me[i].fmt, &fmt_me, sizeof(ng_video_fmt));
     buf_me[i].size = buf_me[i].fmt.bytesperline * buf_me[i].fmt.height;
@@ -1105,25 +1241,25 @@ vpV4l2Grabber::startStreaming()
 
 
     buf_me[i].data = (unsigned char *) v4l2_mmap(NULL, buf_v4l2[i].length,
-						 PROT_READ | PROT_WRITE, 
-						 MAP_SHARED,
-						 fd, (off_t)buf_v4l2[i].m.offset);
+                                                 PROT_READ | PROT_WRITE,
+                                                 MAP_SHARED,
+                                                 fd, (off_t)buf_v4l2[i].m.offset);
 
     if(buf_me[i].data == MAP_FAILED)
     {
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't map memory") );
+                                     "Can't map memory") );
     }
 
     buf_me[i].refcount = 0;
 
-//     if (m_verbose)
-//     {
-//       std::cout << "2: buf_v4l2[" << i << "].length: " << buf_v4l2[i].length
-// 	   << " buf_v4l2[" << i << "].offset: " <<  buf_v4l2[i].m.offset
-// 	   << std::endl;
-//       std::cout << "2: buf_me[" << i << "].size: " << buf_me[i].size << std::endl;
-//     }
+    //     if (m_verbose)
+    //     {
+    //       std::cout << "2: buf_v4l2[" << i << "].length: " << buf_v4l2[i].length
+    // 	   << " buf_v4l2[" << i << "].offset: " <<  buf_v4l2[i].m.offset
+    // 	   << std::endl;
+    //       std::cout << "2: buf_me[" << i << "].size: " << buf_me[i].size << std::endl;
+    //     }
 
     if (m_verbose)
       printBufInfo(buf_v4l2[i]);
@@ -1136,7 +1272,7 @@ vpV4l2Grabber::startStreaming()
   if (v4l2_ioctl(fd, VIDIOC_STREAMON, &fmt_v4l2.type)<0)
   {
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't start streaming") );
+                                   "Can't start streaming") );
   }
 
   streaming = true;
@@ -1151,8 +1287,6 @@ vpV4l2Grabber::startStreaming()
 void
 vpV4l2Grabber::stopStreaming()
 {
-  unsigned int i;
-
   //nothing to do if (fd < 0) or if  (streaming == false)
   if ((fd >= 0) && (streaming == true)) {
 
@@ -1161,17 +1295,17 @@ vpV4l2Grabber::stopStreaming()
     fmt_v4l2.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
     if (v4l2_ioctl(fd, VIDIOC_STREAMOFF,&fmt_v4l2.type)) {
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "Can't stop streaming") );
+                                     "Can't stop streaming") );
     }
     /* free buffers */
-    for (i = 0; i < reqbufs.count; i++) {
+    for (unsigned int i = 0; i < reqbufs.count; i++) {
       if (m_verbose)
-	printBufInfo(buf_v4l2[i]);
+        printBufInfo(buf_v4l2[i]);
       //vpTRACE("v4l2_munmap()");
 
       if (-1 == v4l2_munmap(buf_me[i].data, buf_me[i].size)) {
-	throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				       "Can't unmap memory") );
+        throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
+                                       "Can't unmap memory") );
       }
     }
     queue = 0;
@@ -1201,7 +1335,7 @@ vpV4l2Grabber::waiton(__u32 &index, struct timeval &timestamp)
   fd_set rdset;
 
   /* wait for the next frame */
- again:
+again:
 
   tv.tv_sec  = 30;
   tv.tv_usec = 0;
@@ -1213,12 +1347,12 @@ vpV4l2Grabber::waiton(__u32 &index, struct timeval &timestamp)
       goto again;
     index = 0;
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't access to the frame") );
+                                   "Can't access to the frame") );
     return NULL;
   case  0:
     index = 0;
     throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				   "Can't access to the frame: timeout") );
+                                   "Can't access to the frame: timeout") );
     return NULL;
   }
 
@@ -1233,19 +1367,19 @@ vpV4l2Grabber::waiton(__u32 &index, struct timeval &timestamp)
     {
     case EAGAIN:
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "VIDIOC_DQBUF: EAGAIN") );
+                                     "VIDIOC_DQBUF: EAGAIN") );
       break;
     case EINVAL:
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "VIDIOC_DQBUF: EINVAL") );
+                                     "VIDIOC_DQBUF: EINVAL") );
       break;
     case ENOMEM:
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "VIDIOC_DQBUF: ENOMEM") );
+                                     "VIDIOC_DQBUF: ENOMEM") );
       break;
     default:
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "VIDIOC_DQBUF") );
+                                     "VIDIOC_DQBUF") );
       break;
     }
     return NULL;
@@ -1299,19 +1433,19 @@ vpV4l2Grabber::queueBuffer()
     {
     case EAGAIN:
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "VIDIOC_QBUF: EAGAIN") );
+                                     "VIDIOC_QBUF: EAGAIN") );
       break;
     case EINVAL:
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "VIDIOC_QBUF: EINVAL") );
+                                     "VIDIOC_QBUF: EINVAL") );
       break;
     case ENOMEM:
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "VIDIOC_QBUF: ENOMEM") );
+                                     "VIDIOC_QBUF: ENOMEM") );
       break;
     default:
       throw (vpFrameGrabberException(vpFrameGrabberException::otherError,
-				     "VIDIOC_QBUF") );
+                                     "VIDIOC_QBUF") );
       break;
     }
   }
@@ -1356,11 +1490,55 @@ vpV4l2Grabber::printBufInfo(struct v4l2_buffer buf)
   }
 
   fprintf(stdout,"v4l2: buf %d: %d ad: 0x%lx offset 0x%x+%d (=0x%x),used %d\n",
-	  buf.index, buf.type, buf.m.userptr, buf.m.offset,
-	  buf.length, buf.length, buf.bytesused);
+          buf.index, buf.type, buf.m.userptr, buf.m.offset,
+          buf.length, buf.length, buf.bytesused);
 
 }
 
+/*!
+
+   Operator that allows to capture a grey level image.
+   \param I : The captured image.
+
+   \code
+#include <visp3/sensor/vpV4l2Grabber.h>
+
+int main()
+{
+  vpImage<unsigned char> I;
+  vpV4l2Grabber g;
+  g >> I;
+}
+   \endcode
+ */
+vpV4l2Grabber &vpV4l2Grabber::operator>>(vpImage<unsigned char> &I)
+{
+  this->acquire(I);
+  return *this;
+}
+
+/*!
+
+   Operator that allows to capture a grey level image.
+   \param I : The captured image.
+
+   \code
+#include <visp3/sensor/vpV4l2Grabber.h>
+
+int main()
+{
+  vpImage<vpRGBa> I;
+  vpV4l2Grabber g;
+  g >> I;
+}
+   \endcode
+ */
+vpV4l2Grabber &vpV4l2Grabber::operator>>(vpImage<vpRGBa> &I)
+{
+  this->acquire(I);
+  return *this;
+}
+
 #elif !defined(VISP_BUILD_SHARED_LIBS)
 // Work arround to avoid warning: libvisp_sensor.a(vpV4l2Grabber.cpp.o) has no symbols
 void dummy_vpV4l2Grabber() {};
