@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,6 +50,7 @@
 #include <visp3/core/vpTracker.h>
 #include <visp3/core/vpRect.h>
 #include <visp3/core/vpImagePoint.h>
+#include <visp3/core/vpPolygon.h>
 
 #include <math.h>
 #include <fstream>
@@ -265,6 +266,13 @@ public :
     return (this->mean_gray_level);
   };
 
+  /*!
+  \return a vpPolygon made from the edges of the dot.
+  */
+  vpPolygon getPolygon() const {
+    return (vpPolygon(ip_edges_list));
+  };
+
   /*!
 
     Return the width of the dot.
@@ -293,8 +301,8 @@ public :
 		    unsigned int gray_level_min, unsigned int gray_level_max);
 
   vpDot& operator =(const vpDot& d) ;
-  bool operator ==(const vpDot& d);
-  bool operator !=(const vpDot& d);
+  bool operator ==(const vpDot& d) const;
+  bool operator !=(const vpDot& d) const;
   friend VISP_EXPORT std::ostream& operator<< (std::ostream& os, vpDot& d);
 
   void print(std::ostream& os) { os << *this << std::endl ; }
