@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -178,13 +178,13 @@ vpDot::operator=(const vpDot& d)
 }
 
 bool
-vpDot::operator!=(const vpDot& d)
+vpDot::operator!=(const vpDot& d) const
 {
   return ( cog != d.getCog() );
 }
 
 bool
-vpDot::operator==(const vpDot& d)
+vpDot::operator==(const vpDot& d) const
 {
   return ( cog == d.getCog() );
 }
