@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -184,32 +184,8 @@ public:
   vpMbTracker();
   virtual ~vpMbTracker();
   
-  /*!
-    Display the 3D model at a given position using the given camera parameters 
-    on a grey level image.
-
-    \param I : The image.
-    \param cMo : Pose used to project the 3D model into the image.
-    \param cam : The camera parameters.
-    \param col : The desired color.
-    \param thickness : The thickness of the lines.
-    \param displayFullModel : If true, the full model is displayed (even the non visible surfaces).
-  */
-  virtual void display(const vpImage<unsigned char>& I, const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam,
-                       const vpColor& col , const unsigned int thickness=1, const bool displayFullModel = false)=0;
-  /*!
-    Display the 3D model at a given position using the given camera parameters 
-    on a color (RGBa) image.
-
-    \param I : The image.
-    \param cMo : Pose used to project the 3D model into the image.
-    \param cam : The camera parameters.
-    \param col : The desired color.
-    \param thickness : The thickness of the lines.
-    \param displayFullModel : If true, the full model is displayed (even the non visible surfaces).
-  */
-  virtual void display(const vpImage<vpRGBa>& I, const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam,
-                       const vpColor& col , const unsigned int thickness=1, const bool displayFullModel = false)=0;
+  /** @name Inherited functionalities from vpMbTracker */
+  //@{
 
   /*! Return the angle used to test polygons appearance. */
   virtual inline  double  getAngleAppear() const { return angleAppears; }
@@ -243,12 +219,13 @@ public:
 
   /*!
     Get the error angle between the gradient direction of the model features projected at the resulting pose and their normal.
+    The error is expressed in degree between 0 and 90.
 
     \return the value for the error.
   */
   virtual double getProjectionError() const { return projectionError; }
 
-  virtual vpColVector getEstimatedDoF();
+  virtual vpColVector getEstimatedDoF() const;
 
   /*!
     Return the error vector \f$(s-s^*)\f$ reached after the virtual visual servoing process used to estimate the pose.
@@ -263,12 +240,12 @@ public:
 
     \sa getRobustWeights()
    */
-  virtual vpColVector getError() {
+  virtual vpColVector getError() const {
     return m_error;
   }
 
   /*! Return a reference to the faces structure. */
-  inline  vpMbHiddenFaces<vpMbtPolygon>& getFaces() { return faces;}
+  virtual inline vpMbHiddenFaces<vpMbtPolygon>& getFaces() { return faces;}
 
   /*!
     Get the far distance for clipping.
@@ -297,7 +274,7 @@ public:
 
     \sa getError()
    */
-  virtual vpColVector getRobustWeights() {
+  virtual vpColVector getRobustWeights() const {
     return m_w;
   }
 
@@ -344,7 +321,7 @@ public:
   }
 
   virtual std::pair<std::vector<vpPolygon>, std::vector<std::vector<vpPoint> > > getPolygonFaces(const bool orderPolygons=true,
-      const bool useVisibility=true);
+      const bool useVisibility=true, const bool clipPolygon=false);
 
   /*!
     Get the current pose between the object and the camera.
@@ -353,7 +330,7 @@ public:
 
     \param cMo_ : the pose
   */
-  inline void getPose(vpHomogeneousMatrix& cMo_) const {cMo_ = this->cMo;}
+  virtual inline void getPose(vpHomogeneousMatrix& cMo_) const {cMo_ = this->cMo;}
   
   /*!
     Get the current pose between the object and the camera.
@@ -362,16 +339,7 @@ public:
 
     \return the current pose
   */
-  inline vpHomogeneousMatrix getPose() const {return this->cMo;}
-
-  /* PURE VIRTUAL METHODS */
-
-  /*!
-    Initialise the tracking.
-
-    \param I : Input image.
-  */
-  virtual void init(const vpImage<unsigned char>& I)=0;
+  virtual inline vpHomogeneousMatrix getPose() const {return this->cMo;}
 
   // Intializer
 
@@ -388,25 +356,9 @@ public:
   virtual void initFromPose(const vpImage<unsigned char>& I, const vpHomogeneousMatrix &cMo);
   virtual void initFromPose(const vpImage<unsigned char>& I, const vpPoseVector &cPo);
 
-  /*!
-    Load a config file to parameterise the behavior of the tracker.
-    
-    Pure virtual method to adapt to each tracker.
-    
-    \param configFile : An xml config file to parse.
-  */
-  virtual void loadConfigFile(const std::string& configFile)=0;
-
   virtual void loadModel(const char *modelFile, const bool verbose=false);
   virtual void loadModel(const std::string &modelFile, const bool verbose=false);
 
-  /*!
-    Reset the tracker.
-  */
-  virtual void resetTracker() = 0;
-
-  void savePose(const std::string &filename);
-
   /*!
     Set the angle used to test polygons appearance.
     If the angle between the normal of the polygon and the line going
@@ -416,7 +368,7 @@ public:
 
     \param a : new angle in radian.
   */
-  virtual inline  void    setAngleAppear(const double &a) { angleAppears = a; }
+  virtual inline void setAngleAppear(const double &a) { angleAppears = a; }
 
   /*!
     Set the angle used to test polygons disappearance.
@@ -427,7 +379,7 @@ public:
 
     \param a : new angle in radian.
   */
-  virtual inline  void    setAngleDisappear(const double &a) { angleDisappears = a; }
+  virtual inline void setAngleDisappear(const double &a) { angleDisappears = a; }
   
   /*!
     Set the camera parameters.
@@ -456,7 +408,7 @@ public:
 
     \param displayF : set it to true to display the features.
   */
-  void setDisplayFeatures(const bool displayF) {displayFeatures = displayF;}
+  virtual void setDisplayFeatures(const bool displayF) {displayFeatures = displayF;}
 
   virtual void setEstimatedDoF(const vpColVector& v);
 
@@ -476,31 +428,7 @@ public:
     \param opt : Optimization method to use.
   */
   virtual inline void setOptimizationMethod(const vpMbtOptimizationMethod &opt) { m_optimizationMethod = opt; }
-  
-  /*!
-    Set the pose to be used in entry of the next call to the track() function.
-    This pose will be just used once.
     
-    \warning This function has to be called after the initialisation of the tracker.
-    
-    \param I : image corresponding to the desired pose.
-    \param cdMo : Pose to affect.
-  */
-  virtual void setPose(const vpImage<unsigned char> &I, const vpHomogeneousMatrix& cdMo) = 0;
-  
-  /*!
-    Set the filename used to save the initial pose computed using the 
-    initClick() method. It is also used to read a previous pose in the same method. 
-    If the file is not set then, the initClick() method will create a .0.pos 
-    file in the root directory. This directory is the path to the file given to 
-    the method initClick() used to know the coordinates in the object frame.
-    
-    \param filename : The new filename.
-  */
-  inline void setPoseSavingFilename(const std::string& filename){
-    poseSavingFilename = filename;
-  }
-
   /*!
     Set if the projection error criteria has to be computed.
 
@@ -510,6 +438,34 @@ public:
 
   virtual void setScanLineVisibilityTest(const bool &v){ useScanLine = v; }
 
+  virtual void setOgreVisibilityTest(const bool &v);
+  
+  void savePose(const std::string &filename) const;
+
+#ifdef VISP_HAVE_OGRE
+  /*!
+    Set the ratio of visibility attempts that has to be successful to consider a polygon as visible.
+
+    \sa setNbRayCastingAttemptsForVisibility(const unsigned int &)
+
+    \param ratio : Ratio of succesful attempts that has to be considered. Value has to be between 0.0 (0%) and 1.0 (100%).
+  */
+  void setGoodNbRayCastingAttemptsRatio(const double &ratio) {
+    faces.setGoodNbRayCastingAttemptsRatio(ratio);
+  }
+  /*!
+    Set the number of rays that will be sent toward each polygon for visibility test.
+    Each ray will go from the optic center of the camera to a random point inside the considered polygon.
+
+    \sa setGoodNbRayCastingAttemptsRatio(const unsigned int &)
+
+    \param attempts Number of rays to be sent.
+  */
+  void setNbRayCastingAttemptsForVisibility(const unsigned int &attempts) {
+    faces.setNbRayCastingAttemptsForVisibility(attempts);
+  }
+#endif
+
   /*!
     Enable/Disable the appearance of Ogre config dialog on startup.
 
@@ -524,28 +480,79 @@ public:
     ogreShowConfigDialog = showConfigDialog;
   }
 
-  virtual void setOgreVisibilityTest(const bool &v);
-
-#ifdef VISP_HAVE_OGRE
   /*!
-    Set the number of rays that will be sent toward each polygon for visibility test.
-    Each ray will go from the optic center of the camera to a random point inside the considered polygon.
+    Set the filename used to save the initial pose computed using the
+    initClick() method. It is also used to read a previous pose in the same method.
+    If the file is not set then, the initClick() method will create a .0.pos
+    file in the root directory. This directory is the path to the file given to
+    the method initClick() used to know the coordinates in the object frame.
 
-    \sa setGoodNbRayCastingAttemptsRatio(const unsigned int &)
-
-    \param attempts Number of rays to be sent.
+    \param filename : The new filename.
   */
-  void          setNbRayCastingAttemptsForVisibility(const unsigned int &attempts) { faces.setNbRayCastingAttemptsForVisibility(attempts); }
+  inline void setPoseSavingFilename(const std::string& filename){
+    poseSavingFilename = filename;
+  }
+
+  /* PURE VIRTUAL METHODS */
 
   /*!
-    Set the ratio of visibility attempts that has to be successful to consider a polygon as visible.
+    Display the 3D model at a given position using the given camera parameters
+    on a grey level image.
 
-    \sa setNbRayCastingAttemptsForVisibility(const unsigned int &)
-
-    \param ratio : Ratio of succesful attempts that has to be considered. Value has to be between 0.0 (0%) and 1.0 (100%).
+    \param I : The image.
+    \param cMo : Pose used to project the 3D model into the image.
+    \param cam : The camera parameters.
+    \param col : The desired color.
+    \param thickness : The thickness of the lines.
+    \param displayFullModel : If true, the full model is displayed (even the non visible surfaces).
   */
-  void          setGoodNbRayCastingAttemptsRatio(const double &ratio){ faces.setGoodNbRayCastingAttemptsRatio(ratio); }
-#endif
+  virtual void display(const vpImage<unsigned char>& I, const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam,
+                       const vpColor& col , const unsigned int thickness=1, const bool displayFullModel = false)=0;
+  /*!
+    Display the 3D model at a given position using the given camera parameters
+    on a color (RGBa) image.
+
+    \param I : The image.
+    \param cMo : Pose used to project the 3D model into the image.
+    \param cam : The camera parameters.
+    \param col : The desired color.
+    \param thickness : The thickness of the lines.
+    \param displayFullModel : If true, the full model is displayed (even the non visible surfaces).
+  */
+  virtual void display(const vpImage<vpRGBa>& I, const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam,
+                       const vpColor& col , const unsigned int thickness=1, const bool displayFullModel = false)=0;
+
+  /*!
+    Initialise the tracking.
+
+    \param I : Input image.
+  */
+  virtual void init(const vpImage<unsigned char>& I)=0;
+
+  /*!
+    Load a config file to parameterise the behavior of the tracker.
+
+    Pure virtual method to adapt to each tracker.
+
+    \param configFile : An xml config file to parse.
+  */
+  virtual void loadConfigFile(const std::string& configFile)=0;
+
+  /*!
+    Reset the tracker.
+  */
+  virtual void resetTracker() = 0;
+
+  /*!
+    Set the pose to be used in entry of the next call to the track() function.
+    This pose will be just used once.
+
+    \warning This function has to be called after the initialisation of the tracker.
+
+    \param I : image corresponding to the desired pose.
+    \param cdMo : Pose to affect.
+  */
+  virtual void setPose(const vpImage<unsigned char> &I, const vpHomogeneousMatrix& cdMo) = 0;
 
   /*!
     Test the quality of the tracking.
@@ -553,15 +560,18 @@ public:
     \throw vpException if the test fail.
   */
   virtual void testTracking() = 0;
-  
+
   /*!
     Track the object in the given image
 
     \param I : The current image.
   */
   virtual void track(const vpImage<unsigned char>& I)=0;
+  //@}
 
 protected:
+  /** @name Protected Member Functions Inherited from vpMbTracker */
+  //@{
   void addPolygon(const std::vector<vpPoint>& corners, const int idFace=-1, const std::string &polygonName="",
       const bool useLod=false, const double minPolygonAreaThreshold=2500.0, const double minLineLengthThreshold=50.0);
   void addPolygon(const vpPoint& p1, const vpPoint &p2, const vpPoint &p3, const double radius, const int idFace=-1,
@@ -573,7 +583,7 @@ protected:
 
   void createCylinderBBox(const vpPoint& p1, const vpPoint &p2, const double &radius, std::vector<std::vector<vpPoint> > &listFaces);
 
-  void computeJTR(const vpMatrix& J, const vpColVector& R, vpColVector& JTR);
+  void computeJTR(const vpMatrix& J, const vpColVector& R, vpColVector& JTR) const;
   
 #ifdef VISP_HAVE_COIN3D
   virtual void extractGroup(SoVRMLGroup *sceneGraphVRML2, vpHomogeneousMatrix &transform, int &idFace);
@@ -582,15 +592,16 @@ protected:
   virtual void extractCylinders(SoVRMLIndexedFaceSet* face_set, vpHomogeneousMatrix &transform, int &idFace, const std::string &polygonName="");
 #endif
   
-  vpPoint getGravityCenter(const std::vector<vpPoint>& _pts);
+  vpPoint getGravityCenter(const std::vector<vpPoint>& _pts) const;
   
   /*!
     Add a circle to track from its center, 3 points (including the center) defining the plane that contain
     the circle and its radius.
 
     \param p1 : Center of the circle.
-    \param p2,p3 : Two points on the plane containing the circle. With the center of the circle we have 3 points
-    defining the plane that contains the circle.
+    \param p2 : A point on the plane containing the circle.
+    \param p3 : An other point on the plane containing the circle. With the center of the circle \e p1,
+    \e p2 and \e p3 we have 3 points defining the plane that contains the circle.
     \param radius : Radius of the circle.
     \param idFace : Id of the face associated to the circle.
     \param name : Name of the circle.
@@ -641,19 +652,20 @@ protected:
 
   std::map<std::string, std::string> parseParameters(std::string& endLine);
 
-  inline std::string &ltrim(std::string &s) {
+  inline std::string &ltrim(std::string &s) const {
     s.erase(s.begin(), std::find_if(s.begin(), s.end(), std::not1(std::ptr_fun<int, int>(std::isspace))));
     return s;
   }
 
-  inline std::string &rtrim(std::string &s) {
+  inline std::string &rtrim(std::string &s) const {
     s.erase(std::find_if(s.rbegin(), s.rend(), std::not1(std::ptr_fun<int, int>(std::isspace))).base(), s.end());
     return s;
   }
 
-  inline std::string &trim(std::string &s) {
+  inline std::string &trim(std::string &s) const {
     return ltrim(rtrim(s));
   }
+  //@}
 };
 
 
