@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -287,7 +287,7 @@ vpMbtDistanceCircle::display(const vpImage<unsigned char>&I, const vpHomogeneous
                              const vpCameraParameters &camera, const vpColor col, const unsigned int thickness,
                              const bool displayFullModel )
 {
-  if(isvisible || displayFullModel){
+  if( (isvisible && isTrackedCircle) || displayFullModel){
     // Perspective projection
     circle->changeFrame(cMo);
 
@@ -319,7 +319,7 @@ vpMbtDistanceCircle::display(const vpImage<vpRGBa> &I, const vpHomogeneousMatrix
                              const vpCameraParameters &camera, const vpColor col,
                              const unsigned int thickness, const bool displayFullModel)
 {
-  if(isvisible || displayFullModel){
+  if( (isvisible && isTrackedCircle) || displayFullModel){
     // Perspective projection
     circle->changeFrame(cMo);
 
