@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -749,37 +749,6 @@ void vpTemplateTracker::initFromZone(const vpImage<unsigned char> &I, const vpTe
   }
 }
 
-void vpTemplateTracker::initCompInversePyr(const vpImage<unsigned char> &I)
-{
-  vpTRACE("initCompInversePyr");
-  templateSize=templateSizePyr[0];
-  //ptTemplateSupp=ptTemplateSuppPyr[0];
-  //ptTemplateCompo=ptTemplateCompoPyr[0];
-  ptTemplate=ptTemplatePyr[0];
-  ptTemplateSelect=ptTemplateSelectPyr[0];
-  initCompInversePyr(I);
-  ptTemplateSuppPyr[0]=ptTemplateSupp;
-  ptTemplateCompoPyr[0]=ptTemplateCompo;
-
-
-  if(nbLvlPyr>1)
-  {
-    vpImage<unsigned char> Itemp=I;
-    for(unsigned int i=1;i<nbLvlPyr;i++)
-    {
-      vpImageFilter::getGaussPyramidal(Itemp,Itemp);
-
-      templateSize=templateSizePyr[i];
-      ptTemplate=ptTemplatePyr[i];
-      ptTemplateSelect=ptTemplateSelectPyr[i];
-      initCompInversePyr(Itemp);
-      ptTemplateSuppPyr[i]=ptTemplateSupp;
-      ptTemplateCompoPyr[i]=ptTemplateCompo;
-    }
-  }
-  // 	vpTRACE("fin initCompInversePyr");
-
-}
 void vpTemplateTracker::initHessienDesiredPyr(const vpImage<unsigned char> &I)
 {
   // 	vpTRACE("initHessienDesiredPyr");
