@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -59,6 +59,10 @@
 /*!
   \class vpXmlConfigParserKeyPoint
   \ingroup group_vision_keypoints
+
+  \warning This class is only available if libxml2 is installed and detected by ViSP.
+  Installation instructions are provided here https://visp.inria.fr/3rd_xml2.
+
 */
 class VISP_EXPORT vpXmlConfigParserKeyPoint: public vpXmlParser
 {
@@ -131,6 +135,8 @@ private :
 public:
 
   vpXmlConfigParserKeyPoint();
+  //! Default destructor.
+  virtual ~vpXmlConfigParserKeyPoint() {};
 
   /*!
     Get the detector name.
