@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -792,12 +792,12 @@ int vpCalibration::displayGrid(vpImage<unsigned char> &I, vpColor color,
     double oY = *it_LoY;
     double oZ = *it_LoZ;
 
-    double cX = oX*cMo[0][0]+oY*cMo[0][1]+oZ*cMo[0][2] + cMo[0][3];
-    double cY = oX*cMo[1][0]+oY*cMo[1][1]+oZ*cMo[1][2] + cMo[1][3];
-    double cZ = oX*cMo[2][0]+oY*cMo[2][1]+oZ*cMo[2][2] + cMo[2][3];
+    //double cX = oX*cMo[0][0]+oY*cMo[0][1]+oZ*cMo[0][2] + cMo[0][3];
+    //double cY = oX*cMo[1][0]+oY*cMo[1][1]+oZ*cMo[1][2] + cMo[1][3];
+    //double cZ = oX*cMo[2][0]+oY*cMo[2][1]+oZ*cMo[2][2] + cMo[2][3];
 
-    double x = cX/cZ ;
-    double y = cY/cZ ;
+    //double x = cX/cZ ;
+    //double y = cY/cZ ;
 
     //     double xp = u0 + x*px ;
     //     double yp = v0 + y*py ;
@@ -805,12 +805,12 @@ int vpCalibration::displayGrid(vpImage<unsigned char> &I, vpColor color,
     //     vpDisplay::displayCross(I,(int)vpMath::round(yp), (int)vpMath::round(xp),
     // 			    5,col) ;
 
-    cX = oX*cMo_dist[0][0]+oY*cMo_dist[0][1]+oZ*cMo_dist[0][2]+cMo_dist[0][3];
-    cY = oX*cMo_dist[1][0]+oY*cMo_dist[1][1]+oZ*cMo_dist[1][2]+cMo_dist[1][3];
-    cZ = oX*cMo_dist[2][0]+oY*cMo_dist[2][1]+oZ*cMo_dist[2][2]+cMo_dist[2][3];
+    double cX = oX*cMo_dist[0][0]+oY*cMo_dist[0][1]+oZ*cMo_dist[0][2]+cMo_dist[0][3];
+    double cY = oX*cMo_dist[1][0]+oY*cMo_dist[1][1]+oZ*cMo_dist[1][2]+cMo_dist[1][3];
+    double cZ = oX*cMo_dist[2][0]+oY*cMo_dist[2][1]+oZ*cMo_dist[2][2]+cMo_dist[2][3];
 
-    x = cX/cZ ;
-    y = cY/cZ ;
+    double x = cX/cZ ;
+    double y = cY/cZ ;
 
     double r2 = 1+kud_dist*(vpMath::sqr(x)+vpMath::sqr(y)) ;
 
