@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2015 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -307,7 +307,7 @@ unsigned int  vpKeyPointSurf::buildReference(const vpImage<unsigned char> &I,
 
   vpImage<unsigned char> subImage;
 
-  vpImageTools::createSubImage(I,
+  vpImageTools::crop(I,
 			       (unsigned int)iP.get_i(),
 			       (unsigned int)iP.get_j(),
 			       height, width, subImage);
@@ -484,7 +484,7 @@ unsigned int vpKeyPointSurf::matchPoint(const vpImage<unsigned char> &I,
 
   vpImage<unsigned char> subImage;
 
-  vpImageTools::createSubImage(I,
+  vpImageTools::crop(I,
 			       (unsigned int)iP.get_i(),
 			       (unsigned int)iP.get_j(),
 			       height, width, subImage);
