@@ -8,7 +8,7 @@ int main()
     vpImageIo::read(I, "monkey.jpeg");
     vpImageIo::write(I, "monkey.png");
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << e.getMessage() << std::endl;
   }
   catch(...) {
