@@ -39,7 +39,7 @@ int main()
 
     vpDisplay::getClick(I);
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 }
