@@ -37,7 +37,7 @@ int main()
     robot.stopRunning();
     robot.waitForRunExit();
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 #endif
