@@ -162,7 +162,7 @@ int main()
     task.print();
     task.kill();
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 }
