@@ -72,7 +72,7 @@ int main()
     std::cout << "A click to quit..." << std::endl;
     vpDisplay::getClick(I);
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 }
