@@ -154,7 +154,7 @@ int main(int argc, const char *argv[])
 
     return 0;
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 #else
