@@ -92,7 +92,7 @@ int main()
     vpDisplay::getClick(plotter.I);
 #endif
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 }
