@@ -49,7 +49,7 @@ int main()
 
     task.kill();
   }
-  catch(vpException e) {
+  catch(vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 }
